module TPEX
	class Client
		module PerformanceNodes
			#make sure all of these have a title and product_ref mapping
			NON_SSL_LAMP_FIELDS = {
				color_rendering_index: {machine_name:"field_nnslmp_clrrndrngndx_av", enclosed: true},
				color_rendering_index_src: {machine_name:"field_nnslmp_clrrndrngndx_src"},
				correlated_color_temperature: {machine_name:"field_nnslmp_crltdclrtmprt_av", enclosed: true},
				correlated_color_temperature_src: {machine_name:"field_nnslmp_crltdclrtmprt_src"},
				light_source_type: {machine_name:"field_nnslmp_lghtsrctyp_av"},
				light_source_type_src: {machine_name:"field_nnslmp_lghtsrctyp_src"},
				lamp_distribution_type: {machine_name:"field_nnslmp_lmpdstrbtntyp_av"},
				lamp_distribution_type_src: {machine_name:"field_nnslmp_lmpdstrbtntyp_src"},
				measurement_source: {machine_name:"field_nnslmp_measurement_source"},
				mean_luminous_flux: {machine_name:"field_nnslmp_mnlmnsflx_av", enclosed: true},
				mean_luminous_flux_src: {machine_name:"field_nnslmp_mnlmnsflx_src"},
				mean_luminous_flux_for_horizontal_installations: {machine_name:"field_nnslmp_mnlmnsflxfrhr_av", enclosed: true},
				mean_luminous_flux_hz_src: {machine_name:"field_nnslmp_mnlmnsflxfrhr_src"},
				mean_luminous_flux_for_vertical_installations: {machine_name:"field_nnslmp_mnlmnsflxfrvr_av", enclosed: true},
				mean_lum_vert_src: {machine_name:"field_nnslmp_mnlmnsflxfrvr_src"},
				input_power: {machine_name:"field_nnslmp_nptpwr_av", enclosed: true},
				input_power_src: {machine_name:"field_nnslmp_nptpwr_src"},
				ansi_lamp_designation: {machine_name:"field_nnslmp_nslmpdsgntn_av", enclosed: true},
				ansi_lamp_designation_src: {machine_name:"field_nnslmp_nslmpdsgntn_src"},
				integral_ballast: {machine_name:"field_nnslmp_ntgrlblst_av"},
				integral_ballast_src: {machine_name:"field_nnslmp_ntgrlblst_src"},
				initial_luminous_flux: {machine_name:"field_nnslmp_ntllmnsflx_av", enclosed: true},
				initial_luminous_flux_src: {machine_name:"field_nnslmp_ntllmnsflx_src"},
				product_ref: {machine_name:"field_nnslmp_product_ref"},
				rated_life: {machine_name:"field_nnslmp_rtdlf_av", enclosed: true},
				rated_life_src: {machine_name:"field_nnslmp_rtdlf_src"},
				specification_sheet: {machine_name:"field_nnslmp_spcfctnsht_av", enclosed:true, label: "fid" },
				specification_sheet_src: {machine_name:"field_nnslmp_spcfctnsht_src"},
				standard_photometric_data: {machine_name:"field_nnslmp_stndrdphtmtrc_av", enclosed:true, label: "fid" },
				std_photomet_src: {machine_name:"field_nnslmp_stndrdphtmtrc_src"},
				product_ref: {machine_name:"field_product_ref", required:true},
				title: {machine_name:"title", required:true}
			}
			
			SSL_LAMP_FIELDS = {
				color_rendering_index: {machine_name:"field_slrplc_clrrndrngndx_av", enclosed: true},
				color_rendering_index_src: {machine_name:"field_slrplc_clrrndrngndx_src"},
				correlated_color_temperature: {machine_name:"field_slrplc_crltdclrtmprt_av", enclosed: true},
				correlated_color_temperature_src: {machine_name:"field_slrplc_crltdclrtmprt_src"},
				lumen_maintenance: {machine_name:"field_slrplc_lmnmntnc_av", enclosed: true},
				lumen_maintenance_src: {machine_name:"field_slrplc_lmnmntnc_src"},
				lamp_distribution_type: {machine_name:"field_slrplc_lmpdstrbtntyp_av"},
				lamp_distribution_type_src: {machine_name:"field_slrplc_lmpdstrbtntyp_src"},
				measurement_source: {machine_name:"field_slrplc_measurement_source"},
				input_power: {machine_name:"field_slrplc_nptpwr_av", enclosed: true},
				input_power_src: {machine_name:"field_slrplc_nptpwr_src"},
				ansi_lamp_designation: {machine_name:"field_slrplc_nslmpdsgntn_av", enclosed: true},
				ansi_lamp_designation_src: {machine_name:"field_slrplc_nslmpdsgntn_src"},
				initial_luminous_flux: {machine_name:"field_slrplc_ntllmnsflx_av", enclosed: true},
				initial_luminous_flux_src: {machine_name:"field_slrplc_ntllmnsflx_src"},
				specification_sheet: {machine_name:"field_slrplc_spcfctnsht_av", enclosed:true, label: "fid" },
				specification_sheet_src: {machine_name:"field_slrplc_spcfctnsht_src"},
				standard_photometric_data: {machine_name:"field_slrplc_stndrdphtmtrc_av", enclosed:true, label: "fid" },
				standard_photometric_data_src: {machine_name:"field_slrplc_stndrdphtmtrc_src"},
				product_ref: {machine_name:"field_product_ref", required:true},
				title: {machine_name:"title", required: true}
			}
		
		    PV_MODULE_FIELDS = {
				module_efficiency: {machine_name:"field_phtvlt_mdlfcncy_av", enclosed: true},
				module_efficiency_src: {machine_name:"field_phtvlt_mdlfcncy_src"},
				rated_power: {machine_name:"field_phtvlt_rtdpwr_av", enclosed: true},
				rated_power_src: {machine_name:"field_phtvlt_rtdpwr_src"},
				cell_material: {machine_name:"field_phtvlt_clmtrltyp_av", multiple_list: true},
				cell_material_src: {machine_name:"field_phtvlt_clmtrltyp_src"},
				length: {machine_name:"field_phtvlt_lngth_av", enclosed: true},
				length_src: {machine_name:"field_phtvlt_lngth_src"},
				width: {machine_name:"field_phtvlt_wdth_av", enclosed: true},
				width_src: {machine_name:"field_phtvlt_wdth_src"},
				total_number_cells: {machine_name:"field_phtvlt_ttlnmbrfcls_av", enclosed: true},
				total_number_cells_src: {machine_name:"field_phtvlt_ttlnmbrfcls_src"},
				number_cell_series: {machine_name:"field_phtvlt_nmbrfclsnsrs_av", enclosed: true},
				number_cell_series_src: {machine_name:"field_phtvlt_nmbrfclsnsrs_src"},
				solar_cell_area: {machine_name:"field_phtvlt_slrclr_av", enclosed: true},
				solar_cell_area_src: {machine_name:"field_phtvlt_slrclr_src"},
				nominal_operating_cell_temp: {machine_name:"field_phtvlt_nmnlprtngcltm_av", enclosed: true},
				nominal_operating_cell_temp_src: {machine_name:"field_phtvlt_nmnlprtngcltm_src"},
				short_circuit_current_temp_coef: {machine_name: "field_phtvlt_shrtcrctcrntt_av", enclosed: true},
				short_circuit_current_temp_coef_src: {machine_name: "field_phtvlt_shrtcrctcrntt_src"},
				open_circuit_voltage_temp_coef: {machine_name:"field_phtvlt_pncrctvltgtmp_av", enclosed: true},
				open_circuit_voltage_temp_coef_src: {machine_name:"field_phtvlt_pncrctvltgtmp_src"},
				max_power_temp_coef: {machine_name:"field_phtvlt_mxmpwrtmprtrc_av", enclosed: true},
				max_power_temp_coef_src: {machine_name:"field_phtvlt_mxmpwrtmprtrc_src"},
				max_power_ltc: {machine_name:"field_phtvlt_mxmpwrtltc_av", enclosed: true},
				max_power_ltc_src: {machine_name:"field_phtvlt_mxmpwrtltc_src"},
				max_system_voltage: {machine_name:"field_phtvlt_mxmsystmvltg_av", enclosed: true},
				max_system_voltage_src: {machine_name:"field_phtvlt_mxmsystmvltg_src"},
				max_stress_limit: {machine_name:"field_phtvlt_mxmstrslmt_av", enclosed: true},
				max_stress_limit_src: {machine_name:"field_phtvlt_mxmstrslmt_src"},
				rated_hail_diameter_resistance: {machine_name:"field_phtvlt_rtdhldmtrmpct_av", enclosed: true},
				rated_hail_diameter_resistance_src: {machine_name:"field_phtvlt_rtdhldmtrmpct_src"},
				rated_hail_speed_resistance: {machine_name:"field_phtvlt_rtdhlspdmpctr_av", enclosed: true},
				rated_hail_speed_resistance_src: {machine_name:"field_phtvlt_rtdhlspdmpctr_src"},
				manufacturer_warranty_available: {machine_name:"field_phtvlt_mnfctrswrntyv_av"},
				manufacturer_warranty_available_src: {machine_name:"field_phtvlt_mnfctrswrntyv_src"},
				warranty_time_length: {machine_name:"field_phtvlt_wrntytmlngth_av", enclosed: true},
				warranty_time_length_src: {machine_name:"field_phtvlt_wrntytmlngth_src"},
				percent_pmp_guarantee: {machine_name:"field_phtvlt_prcntpmpgrntd_av", enclosed: true},
				percent_pmp_guarantee_src: {machine_name:"field_phtvlt_prcntpmpgrntd_src"},
				electrical_performance_chart: {machine_name:"field_phtvlt_lctrclprfrmnc_av", enclosed: true, label:"fid"},
				electrical_performance_chart_src: {machine_name:"field_phtvlt_lctrclprfrmnc_src"},
				measurement_source: {machine_name:"field_phtvlt_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			 }
			 
			 
			 HOT_WATER_BOILER_FIELDS = {
				input_power: {machine_name:"field_htwtrb_nptpwr_av", enclosed: true},
				input_power_src: {machine_name:"field_htwtrb_nptpwr_src"},			 
				annual_fuel_utilization_efficiency: {machine_name:"field_htwtrb_nlfltlztnfcnc_av", enclosed: true},
				annual_fuel_utilization_efficiency_src: {machine_name: "field_htwtrb_nlfltlztnfcnc_src"},
				thermal_efficiency: {machine_name:"field_htwtrb_thrmlfcncy_av", enclosed: true},
				thermal_efficiency_src: {machine_name:"field_htwtrb_thrmlfcncy_src"},
				combustion_efficiency: {machine_name:"field_htwtrb_cmbstnfcncy_av", enclosed: true},
				combustion_efficiency_src: {machine_name:"field_htwtrb_cmbstnfcncy_src"},
				fuel_type: {machine_name:"field_htwtrb_fltyp_av", multiple_list: true},
				fuel_type_src: {machine_name:"field_htwtrb_fltyp_src"},
				ahri_certified_reference_number: {machine_name:"field_htwtrb_hrcrtfdrfrncn_av", enclosed: true},
				ahri_certified_reference_number_src: {machine_name:"field_htwtrb_hrcrtfdrfrncn_src"},
				input_power_control: {machine_name:"field_htwtrb_nptpwrcntrl_av"},
				input_power_control_src: {machine_name:"field_htwtrb_nptpwrcntrl_src"},
				number_of_discrete_heating_stages: {machine_name:"field_htwtrb_nmbrfdscrthtn_av", enclosed: true},
				number_of_discrete_heating_stages_src: {machine_name:"field_htwtrb_nmbrfdscrthtn_src"},
				turndown_ratio: {machine_name:"field_htwtrb_trndwnrt_av", enclosed: true},
				turndown_ratio_src: {machine_name:"field_htwtrb_trndwnrt_src"},
				control_options: {machine_name:"field_htwtrb_cntrlptns_av", enclosed: true, label: "fid" },
				control_options_src: {machine_name:"field_htwtrb_cntrlptns_src"},
				boiler_performance_map: {machine_name:"field_htwtrb_blrprfrmncmp_av", enclosed: true, label: "fid" },
				boiler_performance_map_src: {machine_name:"field_htwtrb_blrprfrmncmp_src"},
				product_data_sheet: {machine_name:"field_htwtrb_prdctdtsht_av", enclosed: true, label: "fid" },
				product_data_sheet_src: {machine_name:"field_htwtrb_prdctdtsht_src"},
				minimum_flow_rate: {machine_name:"field_htwtrb_mnmflwrt_av", enclosed: true},
				minimum_flow_rate_src: {machine_name:"field_htwtrb_mnmflwrt_src"},
				maximum_flow_rate: {machine_name:"field_htwtrb_mxmflwrt_av", enclosed: true},
				maximum_flow_rate_src: {machine_name:"field_htwtrb_mxmflwrt_src"},
				minimum_feedwater_temperature: {machine_name:"field_htwtrb_mnmfdwtrtmprt_av", enclosed: true},
				minimum_feedwater_temperature_src: {machine_name:"field_htwtrb_mnmfdwtrtmprt_src"},
				condensing_operation: {machine_name:"field_htwtrb_cndnsngprtn_av"},
				condensing_operation_src: {machine_name:"field_htwtrb_cndnsngprtn_src"},
				measurement_source: {machine_name:"field_htwtrb_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}
				
				
			STEAM_BOILER_FIELDS = {
				input_power: {machine_name:"field_stmblr_nptpwr_av", enclosed: true},
				input_power_src: {machine_name:"field_stmblr_nptpwr_src"},			 
				annual_fuel_utilization_efficiency: {machine_name:"field_stmblr_nlfltlztnfcnc_av", enclosed: true},
				annual_fuel_utilization_efficiency_src: {machine_name: "field_stmblr_nlfltlztnfcnc_src"},
				thermal_efficiency: {machine_name:"field_stmblr_thrmlfcncy_av", enclosed: true},
				thermal_efficiency_src: {machine_name:"field_stmblr_thrmlfcncy_src"},
				combustion_efficiency: {machine_name:"field_stmblr_cmbstnfcncy_av", enclosed: true},
				combustion_efficiency_src: {machine_name:"field_stmblr_cmbstnfcncy_src"},
				fuel_type: {machine_name:"field_stmblr_fltyp_av", multiple_list: true},
				fuel_type_src: {machine_name:"field_stmblr_fltyp_src"},
				ahri_certified_reference_number: {machine_name:"field_stmblr_hrcrtfdrfrncn_av", enclosed: true},
				ahri_certified_reference_number_src: {machine_name:"field_stmblr_hrcrtfdrfrncn_src"},
				input_power_control: {machine_name:"field_stmblr_nptpwrcntrl_av"},
				input_power_control_src: {machine_name:"field_stmblr_nptpwrcntrl_src"},
				number_of_discrete_heating_stages: {machine_name:"field_stmblr_nmbrfdscrthtn_av", enclosed: true},
				number_of_discrete_heating_stages_src: {machine_name:"field_stmblr_nmbrfdscrthtn_src"},
				turndown_ratio: {machine_name:"field_stmblr_trndwnrt_av", enclosed: true},
				turndown_ratio_src: {machine_name:"field_stmblr_trndwnrt_src"},
				control_options: {machine_name:"field_stmblr_cntrlptns_av", enclosed: true, label: "fid" },
				control_options_src: {machine_name:"field_stmblr_cntrlptns_src"},
				boiler_performance_map: {machine_name:"field_stmblr_blrprfrmncmp_av", enclosed: true, label: "fid" },
				boiler_performance_map_src: {machine_name:"field_stmblr_blrprfrmncmp_src"},
				product_data_sheet: {machine_name:"field_stmblr_prdctdtsht_av", enclosed: true, label: "fid" },
				product_data_sheet_src: {machine_name:"field_stmblr_prdctdtsht_src"},
				minimum_operating_pressure: {machine_name:"field_stmblr_mnmprtngprsr_av", enclosed: true},
				minimum_operating_pressure_src: {machine_name:"field_stmblr_mnmprtngprsr_src"},
				maximum_operating_pressure: {machine_name:"field_stmblr_mxmprtngprsr_av", enclosed: true},
				maximum_operating_pressure_src: {machine_name:"field_stmblr_mxmprtngprsr_src"},
				measurement_source: {machine_name:"field_stmblr_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}
			
			
			CHILLER_FIELDS = {
				basin_heater_capacity: {machine_name:"field_lctrcl_bsnhtrcpcty_av", enclosed: true},
				basin_heater_capacity_src: {machine_name:"field_lctrcl_bsnhtrcpcty_src"},
				chiller_control_documentation: {machine_name:"field_lctrcl_chlrcntrldcmn_av", enclosed:true, label: "fid" },
				chiller_control_documentation_src: {machine_name:"field_lctrcl_chlrcntrldcmn_src"},
				compressor_motor_efficiency: {machine_name:"field_lctrcl_cmprsrmtrfcnc_av", enclosed: true},
				compressor_motor_efficiency_src: {machine_name:"field_lctrcl_cmprsrmtrfcnc_src"},
				compressor_motor_type: {machine_name:"field_lctrcl_cmprsrmtrtyp_av"},
				compressor_motor_type_src: {machine_name:"field_lctrcl_cmprsrmtrtyp_src"},
				compressor_type: {machine_name:"field_lctrcl_cmprsrtyp_av"},
				compressor_type_src: {machine_name:"field_lctrcl_cmprsrtyp_src"},
				condenser_pressure_drop: {machine_name:"field_lctrcl_cndnsrprsrdrp_av", enclosed: true},
				condenser_pressure_drop_src: {machine_name:"field_lctrcl_cndnsrprsrdrp_src"},
				condenser_type: {machine_name:"field_lctrcl_cndnsrtyp_av"},
				condenser_type_src: {machine_name:"field_lctrcl_cndnsrtyp_src"},
				design_chilled_water_flow_rate: {machine_name:"field_lctrcl_dsgnchldwtrfl_av", enclosed: true},
				design_chilled_water_flow_rate_src: {machine_name:"field_lctrcl_dsgnchldwtrfl_src"},
				design_chilled_water_supply_temperature: {machine_name:"field_lctrcl_dsgnchldwtrsp_av", enclosed: true},
				design_chilled_water_supply_temperature_src: {machine_name:"field_lctrcl_dsgnchldwtrsp_src"},
				design_condenser_water_flow_rate: {machine_name:"field_lctrcl_dsgncndnsrwtr_av", enclosed: true},
				design_condenser_water_flow_rate_src: {machine_name:"field_lctrcl_dsgncndnsrwtr_src"},
				fan_control: {machine_name:"field_lctrcl_fncntrl_av"},
				fan_control_src: {machine_name:"field_lctrcl_fncntrl_src"},
				ahri_certified_reference_number: {machine_name:"field_lctrcl_hrcrtfdrfrncn_av", enclosed: true},
				ahri_certified_reference_number_src: {machine_name:"field_lctrcl_hrcrtfdrfrncn_src"},
				ahri_rated_coefficient_of_performance: {machine_name:"field_lctrcl_hrtdcfcntfprf_av", enclosed: true},
				ahri_rated_coefficient_of_performance_src: {machine_name:"field_lctrcl_hrtdcfcntfprf_src"},
				measurement_source: {machine_name:"field_lctrcl_measurement_source"},
				minimum_chilled_water_flow_rate: {machine_name:"field_lctrcl_mnmchldwtrflw_av", enclosed: true},
				minimum_chilled_water_flow_rate_src: {machine_name:"field_lctrcl_mnmchldwtrflw_src"},
				minimum_chilled_water_supply_temperature: {machine_name:"field_lctrcl_mnmchldwtrspl_av", enclosed: true},
				minimum_chilled_water_supply_temperature_src: {machine_name:"field_lctrcl_mnmchldwtrspl_src"},
				minimum_condenser_water_flow_rate: {machine_name:"field_lctrcl_mnmcndnsrwtrf_av", enclosed: true},
				minimum_condenser_water_flow_rate_src: {machine_name:"field_lctrcl_mnmcndnsrwtrf_src"},
				minimum_condenser_water_entering_temperature: {machine_name:"field_lctrcl_mnmcndnsrwtrn_av", enclosed: true},
				minimum_condenser_water_entering_temperature_src: {machine_name:"field_lctrcl_mnmcndnsrwtrn_src"},
				minimum_part_load_ratio: {machine_name:"field_lctrcl_mnmprtldrt_av", enclosed: true},
				minimum_part_load_ratio_src: {machine_name:"field_lctrcl_mnmprtldrt_src"},
				minimum_outdoor_air_dry_bulb_temperature: {machine_name:"field_lctrcl_mnmtdrdryblbt_av", enclosed: true},
				minimum_outdoor_air_dry_bulb_temperature_src: {machine_name:"field_lctrcl_mnmtdrdryblbt_src"},
				minimum_outdoor_air_wet_bulb_temperature: {machine_name:"field_lctrcl_mnmtdrwtblbtm_av", enclosed: true},
				minimum_outdoor_air_wet_bulb_temperature_src: {machine_name:"field_lctrcl_mnmtdrwtblbtm_src"},
				maximum_chilled_water_flow_rate: {machine_name:"field_lctrcl_mxmchldwtrflw_av", enclosed: true},
				maximum_chilled_water_flow_rate_src: {machine_name:"field_lctrcl_mxmchldwtrflw_src"},
				maximum_chilled_water_supply_temperature: {machine_name:"field_lctrcl_mxmchldwtrspl_av", enclosed: true},
				maximum_chilled_water_supply_temperature_src: {machine_name:"field_lctrcl_mxmchldwtrspl_src"},
				maximum_condenser_water_flow_rate: {machine_name:"field_lctrcl_mxmcndnsrwtrf_av", enclosed: true},
				maximum_condenser_water_flow_rate_src: {machine_name:"field_lctrcl_mxmcndnsrwtrf_src"},
				maximum_condenser_water_entering_temperature: {machine_name:"field_lctrcl_mxmcndnsrwtrn_av", enclosed: true},
				maximum_condenser_water_entering_temperature_src: {machine_name:"field_lctrcl_mxmcndnsrwtrn_src"},
				maximum_part_load_ratio: {machine_name:"field_lctrcl_mxmprtldrt_av", enclosed: true},
				maximum_part_load_ratio_src: {machine_name:"field_lctrcl_mxmprtldrt_src"},
				maximum_outdoor_air_dry_bulb_temperature: {machine_name:"field_lctrcl_mxmtdrdryblbt_av", enclosed: true},
				maximum_outdoor_air_dry_bulb_temperature_src: {machine_name:"field_lctrcl_mxmtdrdryblbt_src"},
				maximum_outdoor_air_wet_bulb_temperature: {machine_name:"field_lctrcl_mxmtdrwtblbtm_av", enclosed: true},
				maximum_outdoor_air_wet_bulb_temperature_src: {machine_name:"field_lctrcl_mxmtdrwtblbtm_src"},
				net_refrigeration_capacity: {machine_name:"field_lctrcl_ntrfrgrtncpct_av", enclosed: true},
				net_refrigeration_capacity_src: {machine_name:"field_lctrcl_ntrfrgrtncpct_src"},
				product_data_sheet: {machine_name:"field_lctrcl_prdctdtsht_av", enclosed:true, label: "fid" },
				product_data_sheet_src: {machine_name:"field_lctrcl_prdctdtsht_src"},
				performance_map: {machine_name:"field_lctrcl_prfrmncmp_av", enclosed:true, label: "fid" },
				performance_map_src: {machine_name:"field_lctrcl_prfrmncmp_src"},
				part_load_ratio_below_which_hot_gas_bypass_operates: {machine_name:"field_lctrcl_prtldrtblwwhc_av", enclosed: true},
				part_load_ratio_below_which_hot_gas_bypass_operates_src: {machine_name:"field_lctrcl_prtldrtblwwhc_src"},
				refrigerant: {machine_name:"field_lctrcl_rfrgrnt_av"},
				refrigerant_src: {machine_name:"field_lctrcl_rfrgrnt_src"},
				sequence_of_operation: {machine_name:"field_lctrcl_sqncfprtn_av", enclosed:true, label: "fid" },
				sequence_of_operation_src: {machine_name:"field_lctrcl_sqncfprtn_src"},
				evaporator_pressure_drop: {machine_name:"field_lctrcl_vprtrprsrdrp_av", enclosed: true},
				evaporator_pressure_drop_src: {machine_name:"field_lctrcl_vprtrprsrdrp_src"},
				variable_speed_drive_compressor: {machine_name:"field_lctrcl_vrblspddrvcmp_av"},
				variable_speed_drive_compressor_src: {machine_name:"field_lctrcl_vrblspddrvcmp_src"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}
			BALLAST_FIELDS = {
				product_ref: {machine_name:"field_product_ref", required:true},
				ballast_factor: {machine_name:"field_lmpbls_blstfctr_av", enclosed: true},
				ballast_factor_src: {machine_name:"field_lmpbls_blstfctr_src"},
				ballast_type: {machine_name:"field_lmpbls_blsttyp_av"},
				ballast_type_src: {machine_name:"field_lmpbls_blsttyp_src"},
				lamp_distribution_type: {machine_name:"field_lmpbls_lmpdstrbtntyp_av"},
				lamp_distribution_type_src: {machine_name:"field_lmpbls_lmpdstrbtntyp_src"},
				measurement_source: {machine_name:"field_lmpbls_measurement_source"},
				number_of_lamps: {machine_name:"field_lmpbls_nmbrflmps_av", enclosed: true},
				number_of_lamps_src: {machine_name:"field_lmpbls_nmbrflmps_src"},
				input_power_factor_at_120v: {machine_name:"field_lmpbls_nptpwrfctrt12_av", enclosed: true},
				input_power_factor_120v_src: {machine_name:"field_lmpbls_nptpwrfctrt12_src"},
				input_power_factor_at_277v: {machine_name:"field_lmpbls_nptpwrfctrt27_av", enclosed: true},
				input_power_factor_227v_src: {machine_name:"field_lmpbls_nptpwrfctrt27_src"},
				input_power_at_120v: {machine_name:"field_lmpbls_nptpwrt120v_av", enclosed: true},
				input_power_120v_src: {machine_name:"field_lmpbls_nptpwrt120v_src"},
				input_power_at_277v: {machine_name:"field_lmpbls_nptpwrt27v_av", enclosed: true},
				input_power_227v_src: {machine_name:"field_lmpbls_nptpwrt27v_src"},
				input_voltage: {machine_name:"field_lmpbls_nptvltg_av", multiple: true},
				input_voltage_src: {machine_name:"field_lmpbls_nptvltg_src"},
				ansi_lamp_designation: {machine_name:"field_lmpbls_nslmpdsgntn_av", enclosed: true},
				ansi_lamp_src: {machine_name:"field_lmpbls_nslmpdsgntn_src"},
				specification_sheet: {machine_name:"field_lmpbls_spcfctnsht_av", enclosed:true, label: "fid" },
				specification_sheet_src: {machine_name:"field_lmpbls_spcfctnsht_src"},
				starting_method: {machine_name:"field_lmpbls_strtngmthd_av"},
				starting_method_src: {machine_name:"field_lmpbls_strtngmthd_src"},
				total_harmonic_distortion: {machine_name:"field_lmpbls_ttlhrmncdstrt_av", enclosed: true},
				thd_src: {machine_name:"field_lmpbls_ttlhrmncdstrt_src"},
				title: {machine_name:"title", required: true}
			}

			ROOFTOP_UNIT_FIELDS = {
        ahri_certified_reference_number: {machine_name:"field_rftpnt_hrcrtfdrfrncn_av", enclosed: true},
        ahri_certified_reference_number_src: {machine_name:"field_rftpnt_hrcrtfdrfrncn_src"},
        nominal_cooling_capacity: {machine_name:"field_rftpnt_nmnlclngcpcty_av", enclosed: true},
        nominal_cooling_capacity_src: {machine_name:"field_rftpnt_nmnlclngcpcty_src"},
        energy_efficiency_ratio: {machine_name:"field_rftpnt_nrgyfcncyrt_av", enclosed: true},
        energy_efficiency_ratio_src: {machine_name:"field_rftpnt_nrgyfcncyrt_src"},
        integrated_energy_efficiency_ratio: {machine_name:"field_rftpnt_ntgrtdnrgyfcn_av", enclosed: true},
        integrated_energy_efficiency_ratio_src: {machine_name:"field_rftpnt_ntgrtdnrgyfcn_src"},
        seasonal_energy_efficiency_ratio: {machine_name:"field_rftpnt_ssnlnrgyfcncy_av", enclosed:true},
        seasonal_energy_efficiency_ratio_src: {machine_name:"field_rftpnt_ssnlnrgyfcncy_src"},
        cooling_mode_supply_fan_speed_control: {machine_name:"field_rftpnt_clngmdsplyfns_av"},
        cooling_mode_supply_fan_speed_control_src: {machine_name:"field_rftpnt_clngmdsplyfns_src"},
        cooling_mode_number_of_discrete_fan_speeds: {machine_name:"field_rftpnt_clngmdnmbrfds_av", enclosed:true},
        cooling_mode_number_of_discrete_fan_speeds_src: {machine_name:"field_rftpnt_clngmdnmbrfds_src"},
        cooling_mode_minimum_fan_speed_as_a_fraction_of_maximum: {machine_name:"field_rftpnt_clngmdmnmfnsp_av", enclosed:true},
        cooling_mode_minimum_fan_speed_as_a_fraction_of_maximum_src: {machine_name:"field_rftpnt_clngmdmnmfnsp_src"},
        heating_mode_supply_fan_speed_control: {machine_name:"field_rftpnt_htngmdsplyfns_av"},
        heating_mode_supply_fan_speed_control_src: {machine_name:"field_rftpnt_htngmdsplyfns_src"},
        heating_mode_number_of_discrete_fan_speeds: {machine_name:"field_rftpnt_htngmdnmbrfds_av", enclosed: true},
        heating_mode_number_of_discrete_fan_speeds_src: {machine_name:"field_rftpnt_htngmdnmbrfds_src"},
        heating_mode_minimum_fan_speed_as_a_fraction_of_maximum: {machine_name:"field_rftpnt_htngmdmnmfnsp_av", enclosed: true},
        heating_mode_minimum_fan_speed_as_a_fraction_of_maximum_src: {machine_name:"field_rftpnt_htngmdmnmfnsp_src"},
        internal_static_pressure_at_full_speed: {machine_name:"field_rftpnt_ntrnlstcprsrt_av", enclosed: true},
        internal_static_pressure_at_full_speed_src: {machine_name:"field_rftpnt_ntrnlstcprsrt_src"},
        compressor_staging: {machine_name:"field_rftpnt_cmprsrstgng_av"},
        compressor_staging_src: {machine_name:"field_rftpnt_cmprsrstgng_src"},
        number_of_discrete_cooling_stages: {machine_name:"field_rftpnt_nmbrfdscrtcln_av", enclosed: true},
        number_of_discrete_cooling_stages_src: {machine_name:"field_rftpnt_nmbrfdscrtcln_src"},
        degradation_coefficient: {machine_name:"field_rftpnt_dgrdtncfcnt_av", enclosed: true},
        degradation_coefficient_src: {machine_name:"field_rftpnt_dgrdtncfcnt_src"},
        refrigerant: {machine_name:"field_rftpnt_rfrgrnt_av"},
        refrigerant_src: {machine_name:"field_rftpnt_rfrgrnt_src"},
        active_dehumidification: {machine_name:"field_rftpnt_ctvdhmdfctn_av"},
        active_dehumidification_src: {machine_name:"field_rftpnt_ctvdhmdfctn_src"},
        evaporatively_cooled_condenser: {machine_name:"field_rftpnt_vprtvlycldcnd_av"},
        evaporatively_cooled_condenser_src: {machine_name:"field_rftpnt_vprtvlycldcnd_src"},
        minimum_outdoor_dry_bulb_for_cooling_operation: {machine_name:"field_rftpnt_mnmtdrdryblbf_av", enclosed: true},
        minimum_outdoor_dry_bulb_for_cooling_operation_src: {machine_name:"field_rftpnt_mnmtdrdryblbf_src"},
        maximum_outdoor_dry_bulb_for_cooling_operation: {machine_name:"field_rftpnt_mxmtdrdryblbf_av", enclosed: true},
        maximum_outdoor_dry_bulb_for_cooling_operation_src: {machine_name:"field_rftpnt_mxmtdrdryblbf_src"},
        condenser_fan_speed_operation: {machine_name:"field_rftpnt_cndnsrfnspdpr_av"},
        condenser_fan_speed_operation_src: {machine_name:"field_rftpnt_cndnsrfnspdpr_src"},
        air_source_heat_pump: {machine_name:"field_rftpnt_rsrchtpmp_av"},
        air_source_heat_pump_src: {machine_name:"field_rftpnt_rsrchtpmp_src"},
        minimum_outdoor_dry_bulb_for_heat_pump_operation: {machine_name:"field_rftpnt_mnmtdrdryblba_av", enclosed: true},
        minimum_outdoor_dry_bulb_for_heat_pump_operation_src: {machine_name:"field_rftpnt_mnmtdrdryblba_src"},
        maximum_outdoor_dry_bulb_for_heat_pump_operation: {machine_name:"field_rftpnt_mxmtdrdryblba_av", enclosed: true},
        maximum_outdoor_dry_bulb_for_heat_pump_operation_src: {machine_name:"field_rftpnt_mxmtdrdryblba_src"},
        type_of_heating: {machine_name:"field_rftpnt_typfhtng_av", multiple_list: true},
        type_of_heating_src: {machine_name:"field_rftpnt_typfhtng_src"},
        heating_staging: {machine_name:"field_rftpnt_htngstgng_av"},
        heating_staging_src: {machine_name:"field_rftpnt_htngstgng_src"},
        number_of_heating_stages: {machine_name:"field_rftpnt_nmbrfhtngstgs_av", enclosed: true},
        number_of_heating_stages_src: {machine_name:"field_rftpnt_nmbrfhtngstgs_src"},
        burner_turndown_ratio: {machine_name:"field_rftpnt_brnrtrndwnrt_av", enclosed:true},
        burner_turndown_ratio_src: {machine_name:"field_rftpnt_brnrtrndwnrt_src"},
        economizer_control_types_available: {machine_name:"field_rftpnt_cnmzrcntrltyp_av", multiple_list:true},
        economizer_control_types_available_src: {machine_name:"field_rftpnt_cnmzrcntrltyp_src"},
        maximum_oa_flow_rate: {machine_name:"field_rftpnt_mxmflwrt_av", enclosed:true},
        maximum_oa_flow_rate_src: {machine_name:"field_rftpnt_mxmflwrt_src"},
        cooling_performance_map: {machine_name:"field_rftpnt_clngprfrmncmp_av", enclosed:true, label: "fid" },
        cooling_performance_map_src: {machine_name:"field_rftpnt_clngprfrmncmp_src"},
        heat_pump_performance_map: {machine_name:"field_rftpnt_htpmprfrmncmp_av", enclosed:true, label: "fid" },
        heat_pump_performance_map_src: {machine_name:"field_rftpnt_htpmprfrmncmp_src"},
        gas_or_electric_heating_performance_map: {machine_name:"field_rftpnt_gsrlctrchtgpr_av", enclosed:true, label: "fid" },
        gas_or_electric_heating_performance_map_src: {machine_name:"field_rftpnt_gsrlctrchtgpr_src"},
        rtu_control_documentation: {machine_name:"field_rftpnt_rtcntrldcmntn_av", enclosed:true, label: "fid" },
        rtu_control_documentation_src: {machine_name:"field_rftpnt_rtcntrldcmntn_src"},
        product_data_sheet: {machine_name:"field_rftpnt_prdctdtsht_av", enclosed:true, label: "fid" },
        product_data_sheet_src: {machine_name:"field_rftpnt_prdctdtsht_src"},
        product_ref: {machine_name:"field_product_ref", required: true},
        measurement_source: {machine_name:"field_rftpnt_measurement_source"},
        title: {machine_name:"title", required: true}
			}

			SSL_LUMINAIRE_FIELDS = {
				product_ref: {machine_name:"field_product_ref", required: true},
				color_rendering_index: {machine_name:"field_slmnrs_clrrndrngndx_av", enclosed: true},
				color_rendering_index_src: {machine_name:"field_slmnrs_clrrndrngndx_src"},
				correlated_color_temperature: {machine_name:"field_slmnrs_crltdclrtmprt_av", enclosed: true},
				correlated_color_temperature_src: {machine_name:"field_slmnrs_crltdclrtmprt_src"},
				lumen_maintenance: {machine_name:"field_slmnrs_lmnmntnc_av", enclosed: true},
				lumen_maintenance_src: {machine_name:"field_slmnrs_lmnmntnc_src"},
				luminous_efficacy: {machine_name:"field_slmnrs_lmnsfcy_av", enclosed: true},
				luminous_efficacy_src: {machine_name:"field_slmnrs_lmnsfcy_src"},
				lamp_distribution_type: {machine_name:"field_slmnrs_lmpdstrbtntyp_av"},
				lamp_distribution_type_src: {machine_name:"field_slmnrs_lmpdstrbtntyp_src"},
				measurement_source: {machine_name:"field_slmnrs_measurement_source"},
				mounting_type: {machine_name:"field_slmnrs_mntngtyp_av"},
				mounting_type_src: {machine_name:"field_slmnrs_mntngtyp_src"},
				input_power: {machine_name:"field_slmnrs_nptpwr_av", enclosed: true},
				input_power_src: {machine_name:"field_slmnrs_nptpwr_src"},
				input_power_factor: {machine_name:"field_slmnrs_nptpwrfctr_av", enclosed: true},
				input_power_factor_src: {machine_name:"field_slmnrs_nptpwrfctr_src"},
				input_voltage: {machine_name:"field_slmnrs_nptvltg_av", multiple:true},
				input_voltage_src: {machine_name:"field_slmnrs_nptvltg_src"},
				specification_sheet: {machine_name:"field_slmnrs_spcfctnsht_av", enclosed:true, label: "fid" },
				specification_sheet_src: {machine_name:"field_slmnrs_spcfctnsht_src"},
				standard_photometric_data: {machine_name:"field_slmnrs_stndrdphtmtrc_av", enclosed:true, label: "fid" },
				std_photometric_data_src: {machine_name:"field_slmnrs_stndrdphtmtrc_src"},
				total_harmonic_distortion: {machine_name:"field_slmnrs_ttlhrmncdstrt_av", enclosed: true},
				thd_src: {machine_name:"field_slmnrs_ttlhrmncdstrt_src"},
				total_luminous_flux: {machine_name:"field_slmnrs_ttllmnsflx_av", enclosed: true},
				total_luminous_flux_src: {machine_name:"field_slmnrs_ttllmnsflx_src"},
				title: {machine_name:"title", required: true}
			}

			NON_SSL_LUMINAIRE_FIELDS = {
				light_source_type: {machine_name:"field_nnslmn_lghtsrctyp_av"},
				light_source_type_src: {machine_name:"field_nnslmn_lghtsrctyp_src"},
				lamp_distribution_type: {machine_name:"field_nnslmn_lmpdstrbtntyp_av"},
				lamp_distribution_type_src: {machine_name:"field_nnslmn_lmpdstrbtntyp_src"},
				measurement_source: {machine_name:"field_nnslmn_measurement_source"},
				mounting_type: {machine_name:"field_nnslmn_mntngtyp_av"},
				mounting_type_src: {machine_name:"field_nnslmn_mntngtyp_src"},
				number_of_lamps: {machine_name:"field_nnslmn_nmbrflmps_av", enclosed: true},
				number_of_lamps_src: {machine_name:"field_nnslmn_nmbrflmps_src"},
				ansi_lamp_designation: {machine_name:"field_nnslmn_nslmpdsgntn_av", enclosed: true},
				ansi_lamp_designation_src: {machine_name:"field_nnslmn_nslmpdsgntn_src"},
				reference_input_power: {machine_name:"field_nnslmn_rfrncnptpwr_av", enclosed: true},
				reference_input_power_src: {machine_name:"field_nnslmn_rfrncnptpwr_src"},
				reference_input_voltage: {machine_name:"field_nnslmn_rfrncnptvltg_av", enclosed: true},
				reference_input_voltage_src: {machine_name:"field_nnslmn_rfrncnptvltg_src"},
				specification_sheet: {machine_name:"field_nnslmn_spcfctnsht_av", enclosed:true, label: "fid" },
				specification_sheet_src: {machine_name:"field_nnslmn_spcfctnsht_src"},
				standard_photometric_data: {machine_name:"field_nnslmn_stndrdphtmtrc_av", enclosed:true, label: "fid" },
				standard_photometric_data_src: {machine_name:"field_nnslmn_stndrdphtmtrc_src"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			HEAT_PUMP_WATER_HEATER_FIELDS = {
				rated_capacity: {machine_name:"field_htpmpw_rtdcpcty_av", enclosed: true},
				rated_capacity_src: {machine_name:"field_htpmpw_rtdcpcty_src"},
				rated_tank_volume: {machine_name:"field_htpmpw_rtdtnkvlm_av", enclosed: true},
				rated_tank_volume_src: {machine_name:"field_htpmpw_rtdtnkvlm_src"},
				actual_tank_volume: {machine_name:"field_htpmpw_ctltnkvlm_av", enclosed: true},
				actual_tank_volume_src: {machine_name:"field_htpmpw_ctltnkvlm_src"},
				storage_tank_height: {machine_name:"field_htpmpw_strgtnkhght_av", enclosed: true},
				storage_tank_height_src: {machine_name:"field_htpmpw_strgtnkhght_src"},
				required_height_necessary_for_installation: {machine_name:"field_htpmpw_rqrdhghtncsry_av", enclosed: true},
				required_height_necessary_for_installation_src: {machine_name:"field_htpmpw_rqrdhghtncsry_src"},
				rated_coefficient_of_performance: {machine_name:"field_htpmpw_rtdcfcntfprfr_av", enclosed: true},
				rated_coefficient_of_performance_src: {machine_name:"field_htpmpw_rtdcfcntfprfr_src"},
				rated_heat_pump_sensible_heat_ratio: {machine_name:"field_htpmpw_rtdhtpmpsnsbl_av", enclosed: true},
				rated_heat_pump_sensible_heat_ratio_src: {machine_name:"field_htpmpw_rtdhtpmpsnsbl_src"},
				refrigerant_designation: {machine_name:"field_htpmpw_rfrgrntdsgntn_av"},
				refrigerant_designation_src: {machine_name:"field_htpmpw_rfrgrntdsgntn_src"},
				upper_supplemental_heater_capacity: {machine_name:"field_htpmpw_prsplmntlhtrc_av", enclosed: true},
				upper_supplemental_heater_capacity_src: {machine_name:"field_htpmpw_prsplmntlhtrc_src"},
				lower_supplemental_heater_capacity: {machine_name:"field_htpmpw_lwrsplmntlhtr_av", enclosed: true},
				lower_supplemental_heater_capacity_src: {machine_name:"field_htpmpw_lwrsplmntlhtr_src"},
				parasitic_fuel_consumption_rate: {machine_name:"field_htpmpw_prstcflcnsmpt_av", enclosed: true},
				parasitic_fuel_consumption_rate_src: {machine_name:"field_htpmpw_prstcflcnsmpt_src"},
				rated_inlet_air_dry_bulb_temperature: {machine_name:"field_htpmpw_rtdnltrdryblb_av", enclosed: true},
				rated_inlet_air_dry_bulb_temperature_src: {machine_name:"field_htpmpw_rtdnltrdryblb_src"},
				rated_inlet_air_wet_bulb_temperature: {machine_name:"field_htpmpw_rtdnltrwtblbt_av", enclosed: true},
				rated_inlet_air_wet_bulb_temperature_src: {machine_name:"field_htpmpw_rtdnltrwtblbt_src"},
				rated_air_volumetric_flow_rate: {machine_name:"field_htpmpw_rtdrvlmtrcflw_av", enclosed: true},
				rated_air_volumetric_flow_rate_src: {machine_name:"field_htpmpw_rtdrvlmtrcflw_src"},
				off_cycle_heat_loss_coefficient: {machine_name:"field_htpmpw_fcyclhtlscfcn_av", enclosed: true},
				off_cycle_heat_loss_coefficient_src: {machine_name:"field_htpmpw_fcyclhtlscfcn_src"},
				minimum_ambient_air_temperature_for_compressor_operation: {machine_name:"field_htpmpw_mnmbntrtmprtr_av", enclosed: true},
				minimum_ambient_air_temperature_for_compressor_operation_src: {machine_name:"field_htpmpw_mnmbntrtmprtr_src"},
				heat_pump_fan_total_efficiency: {machine_name:"field_htpmpw_htpmpfnttlfcn_av", enclosed: true},
				heat_pump_fan_total_efficiency_src: {machine_name:"field_htpmpw_htpmpfnttlfcn_src"},
				heat_pump_fan_rated_power_input: {machine_name:"field_htpmpw_htpmpfnrtdpwr_av", enclosed: true},
				heat_pump_fan_rated_power_input_src: {machine_name:"field_htpmpw_htpmpfnrtdpwr_src"},
				performance_map: {machine_name:"field_htpmpw_prfrmncmp_av", enclosed:true, label: "fid" },
				performance_map_src: {machine_name:"field_htpmpw_prfrmncmp_src"},
				hpwh_control_details: {machine_name:"field_htpmpw_hpwhcntrldtls_av", enclosed:true, label: "fid" },
				hpwh_control_details_src: {machine_name:"field_htpmpw_hpwhcntrldtls_src"},
			        measurement_source: {machine_name:"field_htpmpw_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}				
			}

		      INVERTER_FIELDS = {
			        maximum_input_power: {machine_name:"field_nvrtr_mxmnptpwr_av", enclosed:true},
			        maximum_input_power_src: {machine_name:"field_nvrtr_mxmnptpwr_src"},
			        peak_efficiency: {machine_name:"field_nvrtr_pkfcncy_av", enclosed:true},
			        peak_efficiency_src: {machine_name:"field_nvrtr_pkfcncy_src"},
			        maximum_continuous_output_power: {machine_name:"field_nvrtr_mxmcntnstptpw_av", enclosed:true},
			        maximum_continuous_output_power_src: {machine_name:"field_nvrtr_mxmcntnstptpw_src"},
			        output_voltages: {machine_name:"field_nvrtr_tptvltgs_av", multiple_list:true},
			        output_voltages_src: {machine_name:"field_nvrtr_tptvltgs_src"},
			        weighted_efficiency_120v: {machine_name:"field_nvrtr_wghtdfcncyt12_av", enclosed:true},
			        weighted_efficiency_120v_src: {machine_name:"field_nvrtr_wghtdfcncyt12_src"},
			        weighted_efficiency_208v: {machine_name:"field_nvrtr_wghtdfcncyt20_av", enclosed:true},
			        weighted_efficiency_208v_src: {machine_name:"field_nvrtr_wghtdfcncyt20_src"},
			        weighted_efficiency_220v: {machine_name:"field_nvrtr_wghtdfcncyt22_av", enclosed:true},
			        weighted_efficiency_220v_src: {machine_name:"field_nvrtr_wghtdfcncyt22_src"},
			        weighted_efficiency_240v: {machine_name:"field_nvrtr_wghtdfcncyt24_av", enclosed:true},
			        weighted_efficiency_240v_src: {machine_name:"field_nvrtr_wghtdfcncyt24_src"},
			        weighted_efficiency_277v: {machine_name:"field_nvrtr_wghtdfcncyt27_av", enclosed:true},
			        weighted_efficiency_277v_src: {machine_name:"field_nvrtr_wghtdfcncyt27_src"},
			        weighted_efficiency_480v: {machine_name:"field_nvrtr_wghtdfcncyt48_av", enclosed:true},
			        weighted_efficiency_480v_src: {machine_name:"field_nvrtr_wghtdfcncyt48_src"},
			        weighted_efficiency_600v: {machine_name:"field_nvrtr_wghtdfcncyt60_av", enclosed:true},
			        weighted_efficiency_600v_src: {machine_name:"field_nvrtr_wghtdfcncyt60_src"},
			        weighted_efficiency_690v: {machine_name:"field_nvrtr_wghtdfcncyt69_av", enclosed:true},
			        weighted_efficiency_690v_src: {machine_name:"field_nvrtr_wghtdfcncyt69_src"},
			        connection_design: {machine_name:"field_nvrtr_cnctndsgn_av", multiple_list:true},
			        connection_design_src: {machine_name:"field_nvrtr_cnctndsgn_src"},
			        output_phase: {machine_name:"field_nvrtr_tptphs_av"},
			        output_phase_src: {machine_name:"field_nvrtr_tptphs_src"},
			        minimum_input_voltage: {machine_name:"field_nvrtr_mnmnptvltg_av", enclosed:true},
			        minimum_input_voltage_src: {machine_name:"field_nvrtr_mnmnptvltg_src"},
			        nominal_input_voltage: {machine_name:"field_nvrtr_nmnlnptvltg_av", enclosed:true},
			        nominal_input_voltage_src: {machine_name:"field_nvrtr_nmnlnptvltg_src"},
			        maximum_input_voltage: {machine_name:"field_nvrtr_mxmnptvltg_av", enclosed:true},
			        maximum_input_voltage_src: {machine_name:"field_nvrtr_mxmnptvltg_src"},
			        standby_power: {machine_name:"field_nvrtr_stndbypwr_av", enclosed:true},
			        standby_power_src: {machine_name:"field_nvrtr_stndbypwr_src"},
			        manufacturer_warranty_available: {machine_name:"field_nvrtr_mnfctrwrntyvl_av"},
			        manufacturer_warranty_available_src: {machine_name:"field_nvrtr_mnfctrwrntyvl_src"},
			        warranty_time_length: {machine_name:"field_nvrtr_wrntytmlngth_av", enclosed:true},
			        warranty_time_length_src: {machine_name:"field_nvrtr_wrntytmlngth_src"},
			        conversion_efficiency_performance_map: {machine_name:"field_nvrtr_cnvrsnfcncypr_av", enclosed:true, label: "fid"},
			        conversion_efficiency_performance_map_src: {machine_name:"field_nvrtr_cnvrsnfcncypr_src"},
			        measurement_source: {machine_name:"field_nvrtr_measurement_source"},
			        product_ref: {machine_name:"field_product_ref", required: true},
			        title: {machine_name:"title", required: true}
		      }

			INDOOR_UNIT_FIELDS = {
				rated_cooling_capacity: {machine_name:"field_ndrnt_rtdclngcpcty_av", enclosed:true},
				rated_cooling_capacity_src: {machine_name:"field_ndrnt_rtdclngcpcty_src"},
				rated_cooling_sensible_heat_ratio: {machine_name:"field_ndrnt_rtdclngsnsblh_av", enclosed:true},
				rated_cooling_sensible_heat_ratio_src: {machine_name:"field_ndrnt_rtdclngsnsblh_src"},
				rated_heating_capacity: {machine_name:"field_ndrnt_rtdhtngcpcty_av", enclosed:true},
				rated_heating_capacity_src: {machine_name:"field_ndrnt_rtdhtngcpcty_src"},
				working_refrigerant: {machine_name:"field_ndrnt_wrkngrfrgrnt_av"},
				working_refrigerant_src: {machine_name:"field_ndrnt_wrkngrfrgrnt_src"},
				mounting_technique: {machine_name:"field_ndrnt_mntngtchnq_av"},
				mounting_technique_src: {machine_name:"field_ndrnt_mntngtchnq_src"},
				rated_cooling_air_flow_rate: {machine_name:"field_ndrnt_rtdclngrflwrt_av", enclosed:true},
				rated_cooling_air_flow_rate_src: {machine_name:"field_ndrnt_rtdclngrflwrt_src"},
				rated_heating_air_flow_rate: {machine_name:"field_ndrnt_rtdhtngrflwrt_av", enclosed:true},
				rated_heating_air_flow_rate_src: {machine_name:"field_ndrnt_rtdhtngrflwrt_src"},
				total_fan_efficiency: {machine_name:"field_ndrnt_ttlfnfcncy_av", enclosed:true},
				total_fan_efficiency_src: {machine_name:"field_ndrnt_ttlfnfcncy_src"},
				fan_power_input: {machine_name:"field_ndrnt_fnpwrnpt_av", enclosed:true},
				fan_power_input_src: {machine_name:"field_ndrnt_fnpwrnpt_src"},
				cooling_performance_map: {machine_name:"field_ndrnt_clngprfrmncmp_av", enclosed:true, label: "fid"},
				cooling_performance_map_src: {machine_name:"field_ndrnt_clngprfrmncmp_src"},
				heating_performance_map: {machine_name:"field_ndrnt_htngprfrmncmp_av", enclosed:true, label: "fid"},
				heating_performance_map_src: {machine_name:"field_ndrnt_htngprfrmncmp_src"},
				measurement_source: {machine_name:"field_ndrnt_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			OUTDOOR_UNIT_FIELDS = {
				rated_total_cooling_capacity: {machine_name:"field_tdrnt_rtdttlclngcpc_av", enclosed:true},
				rated_total_cooling_capacity_src: {machine_name:"field_tdrnt_rtdttlclngcpc_src"},
				rated_cooling_coefficient: {machine_name:"field_tdrnt_rtdclngcfcntf_av", enclosed:true},
				rated_cooling_coefficient_src: {machine_name:"field_tdrnt_rtdclngcfcntf_src"},
				rated_heating_capacity: {machine_name:"field_tdrnt_rtdhtngcpcty_av", enclosed:true},
				rated_heating_capacity_src: {machine_name:"field_tdrnt_rtdhtngcpcty_src"},
				rated_heating_coefficient: {machine_name:"field_tdrnt_rtdhtngcfcntf_av", enclosed:true},
				rated_heating_coefficient_src: {machine_name:"field_tdrnt_rtdhtngcfcntf_src"},
				integrated_energy_efficiency_ratio: {machine_name:"field_tdrnt_ntgrtdnrgyfcn_av", enclosed:true},
				integrated_energy_efficiency_ratio_src: {machine_name:"field_tdrnt_ntgrtdnrgyfcn_src"},
				working_refrigerant: {machine_name:"field_tdrnt_wrkngrfrgrnt_av"},
				working_refrigerant_src: {machine_name:"field_tdrnt_wrkngrfrgrnt_src"},
				defrost_mechanism: {machine_name:"field_tdrnt_dfrstmchnsm_av"},
				defrost_mechanism_src: {machine_name:"field_tdrnt_dfrstmchnsm_src"},
				defrost_control_strategy: {machine_name:"field_tdrnt_dfrstcntrlstr_av"},
				defrost_control_strategy_src: {machine_name:"field_tdrnt_dfrstcntrlstr_src"},
				resistance_capacity: {machine_name:"field_tdrnt_rstnccpcty_av", enclosed:true},
				resistance_capacity_src: {machine_name:"field_tdrnt_rstnccpcty_src"},
				crankcase_heater_power: {machine_name:"field_tdrnt_crnkcshtrpwr_av", enclosed:true},
				crankcase_heater_power_src: {machine_name:"field_tdrnt_crnkcshtrpwr_src"},
				number_compressors: {machine_name:"field_tdrnt_nmbrfcmprsrs_av", enclosed:true},
				number_compressors_src: {machine_name:"field_tdrnt_nmbrfcmprsrs_src"},
				heat_recovery_capability: {machine_name:"field_tdrnt_htrcvrycpblty_av"},
				heat_recovery_capability_src: {machine_name:"field_tdrnt_htrcvrycpblty_src"},
				minimum_temp_heat_recovery: {machine_name:"field_tdrnt_mnmtmprtrfrht_av", enclosed:true},
				minimum_temp_heat_recovery_src: {machine_name:"field_tdrnt_mnmtmprtrfrht_src"},
				maximum_temp_heat_recovery: {machine_name:"field_tdrnt_mxmtmprtrfrht_av", enclosed:true},
				maximum_temp_heat_recovery_src: {machine_name:"field_tdrnt_mxmtmprtrfrht_src"},
				cooling_performance_map: {machine_name:"field_tdrnt_clngprfrmncmp_av", enclosed:true, label: "fid"},
				cooling_performance_map_src: {machine_name:"field_tdrnt_clngprfrmncmp_src"},
				heating_performance_map: {machine_name:"field_tdrnt_htngprfrmncmp_av", enclosed:true, label: "fid"},
				heating_performance_map_src: {machine_name:"field_tdrnt_htngprfrmncmp_src"},
				defrost_performance_map: {machine_name:"field_tdrnt_dfrstprfrmncm_av", enclosed:true, label: "fid"},
				defrost_performance_map_src: {machine_name:"field_tdrnt_dfrstprfrmncm_src"},
				measurement_source: {machine_name:"field_tdrnt_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			UNIT_HEATER_FIELDS = {
				unit_configuration: {machine_name:"field_gsfrdn_ntcnfgrtn_av"},
				unit_configuration_src: {machine_name:"field_gsfrdn_ntcnfgrtn_src"},
				rated_heating_input_capacity: {machine_name:"field_gsfrdn_rtdhtngnptcpc_av", enclosed:true},
				rated_heating_input_capacity_src: {machine_name:"field_gsfrdn_rtdhtngnptcpc_src"},
				rated_gas_burner_efficiency: {machine_name:"field_gsfrdn_rtdgsbrnrfcnc_av", enclosed:true},
				rated_gas_burner_efficiency_src: {machine_name:"field_gsfrdn_rtdgsbrnrfcnc_src"},
				rated_supply_airflow_rate: {machine_name:"field_gsfrdn_rtdsplyrflwrt_av", enclosed:true},
				rated_supply_airflow_rate_src: {machine_name:"field_gsfrdn_rtdsplyrflwrt_src"},
				fuel_type: {machine_name:"field_gsfrdn_fltyp_av", multiple_list:true},
				fuel_type_src: {machine_name:"field_gsfrdn_fltyp_src"},
				rated_voltage: {machine_name:"field_gsfrdn_rtdvltg_av", enclosed:true},
				rated_voltage_src: {machine_name:"field_gsfrdn_rtdvltg_src"},
				phase: {machine_name:"field_gsfrdn_phs_av"},
				phase_src: {machine_name:"field_gsfrdn_phs_src"},
				frequency: {machine_name:"field_gsfrdn_frqncy_av"},
				frequency_src: {machine_name:"field_gsfrdn_frqncy_src"},
				exhaust_fan_flow_rate: {machine_name:"field_gsfrdn_xhstfnflwrt_av", enclosed:true},
				exhaust_fan_flow_rate_src: {machine_name:"field_gsfrdn_xhstfnflwrt_src"},
				exhaust_fan_power_input: {machine_name:"field_gsfrdn_xhstfnpwrnpt_av", enclosed:true},
				exhaust_fan_power_input_src: {machine_name:"field_gsfrdn_xhstfnpwrnpt_src"},
				fan_control: {machine_name:"field_gsfrdn_fncntrl_av"},
				fan_control_src: {machine_name:"field_gsfrdn_fncntrl_src"},
				supply_fan_pressure_rise: {machine_name:"field_gsfrdn_splyfnprsrrs_av", enclosed:true},
				supply_fan_pressure_rise_src: {machine_name:"field_gsfrdn_splyfnprsrrs_src"},
				motor_efficiency: {machine_name:"field_gsfrdn_mtrfcncy_av", enclosed:true},
				motor_efficiency_src: {machine_name:"field_gsfrdn_mtrfcncy_src"},
				parasitic_electric_load: {machine_name:"field_gsfrdn_prstclctrcld_av", enclosed:true},
				parasitic_electric_load_src: {machine_name:"field_gsfrdn_prstclctrcld_src"},
				parasitic_gas_load: {machine_name:"field_gsfrdn_prstcgsld_av", enclosed:true},
				parasitic_gas_load_src: {machine_name:"field_gsfrdn_prstcgsld_src"},
				product_data_sheet: {machine_name:"field_gsfrdn_prdctdtsht_av", enclosed:true, label: "fid" },
				product_data_sheet_src: {machine_name:"field_gsfrdn_prdctdtsht_src"},
				measurement_source: {machine_name:"field_gsfrdn_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			COMPRESSOR_FIELDS = {
				compressor_type: {machine_name:"field_pstvds_cmprsrtyp_av"},
				compressor_type_src:{machine_name:"field_pstvds_cmprsrtyp_src"},
				compressor_style: {machine_name:"field_pstvds_cmprsrstyl_av"},
				compressor_style_src: {machine_name:"field_pstvds_cmprsrstyl_src"},
				rated_capacity: {machine_name:"field_pstvds_rtdcpcty_av", enclosed:true},
				rated_capacity_src: {machine_name:"field_pstvds_rtdcpcty_src"},
				energy_efficiency_ratio: {machine_name:"field_pstvds_nrgyfcncyrt_av", enclosed:true},
				energy_efficiency_ratio_src: {machine_name:"field_pstvds_nrgyfcncyrt_src"},
				application: {machine_name:"field_pstvds_plctn_av"},
				application_src: {machine_name:"field_pstvds_plctn_src"},
				refrigerant: {machine_name:"field_pstvds_rfrgrnt_av", multiple_list:true},
				refrigerant_src: {machine_name:"field_pstvds_rfrgrnt_src"},
				rated_superheat: {machine_name:"field_pstvds_rtdsprht_av", enclosed:true},
				rated_superheat_src: {machine_name:"field_pstvds_rtdsprht_src"},
				rated_subcooling: {machine_name:"field_pstvds_rtdsbclng_av", enclosed:true},
				rated_subcooling_src: {machine_name:"field_pstvds_rtdsbclng_src"},
				minimum_evaporating_temperature: {machine_name:"field_pstvds_mnmvprtngtmpr_av", enclosed:true},
				minimum_evaporating_temperature_src: {machine_name:"field_pstvds_mnmvprtngtmpr_src"},
				maximum_evaporating_temperature: {machine_name:"field_pstvds_mxmvprtngtmpr_av", enclosed:true},
				maximum_evaporating_temperature_src: {machine_name:"field_pstvds_mxmvprtngtmpr_src"},
				minimum_condensing_temperature: {machine_name:"field_pstvds_mnmcndnsngtmp_av", enclosed:true},
				minimum_condensing_temperature_src: {machine_name:"field_pstvds_mnmcndnsngtmp_src"},
				maximum_condensing_temperature: {machine_name:"field_pstvds_mxmcndnsngtmp_av", enclosed:true},
				maximum_condensing_temperature_src: {machine_name:"field_pstvds_mxmcndnsngtmp_src"},
				minimum_suction_pressure: {machine_name:"field_pstvds_mnmsctnprsr_av", enclosed:true},
				minimum_suction_pressure_src: {machine_name:"field_pstvds_mnmsctnprsr_src"},
				maximum_suction_pressure: {machine_name:"field_pstvds_mxmsctnprsr_av", enclosed:true},
				maximum_suction_pressure_src: {machine_name:"field_pstvds_mxmsctnprsr_src"},
				minimum_discharge_pressure: {machine_name:"field_pstvds_mnmdschrgprsr_av", enclosed:true},
				minimum_discharge_pressure_src: {machine_name:"field_pstvds_mnmdschrgprsr_src"},
				maximum_discharge_pressure: {machine_name:"field_pstvds_mxmdschrgprsr_av", enclosed:true},
				maximum_discharge_pressure_src: {machine_name:"field_pstvds_mxmdschrgprsr_src"},
				variable_capacity: {machine_name:"field_pstvds_vrblcpcty_av"},
				variable_capacity_src: {machine_name:"field_pstvds_vrblcpcty_src"},
				input_power_and_capacity_ratings_coefficients: {machine_name:"field_pstvds_nptpwrndcpcty_av", enclosed:true, label:"fid"},
				input_power_and_capacity_ratings_coefficients_src: {machine_name:"field_pstvds_nptpwrndcpcty_src"},
				product_data_sheet: {machine_name:"field_pstvds_prdctdtsht_av", enclosed:true, label:"fid"},
				product_data_sheet_src: {machine_name:"field_pstvds_prdctdtsht_src"},
				performance_map: {machine_name:"field_pstvds_prfrmncmp_av", enclosed:true, label:"fid"},
				performance_map_src: {machine_name:"field_pstvds_prfrmncmp_src"},
				measurement_source: {machine_name:"field_pstvds_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			PUMP_FIELDS = {
				rated_flow_rate: {machine_name:"field_rtdynm_rtdflwrt_av", enclosed:true},
				rated_flow_rate_src: {machine_name:"field_rtdynm_rtdflwrt_src"},
				rated_pump_head: {machine_name:"field_rtdynm_rtdpmphd_av", enclosed:true},
				rated_pump_head_src: {machine_name:"field_rtdynm_rtdpmphd_src"},
				maximum_impeller_diameter: {machine_name:"field_rtdynm_mxmplrdmtr_av", enclosed:true},
				maximum_impeller_diameter_src: {machine_name:"field_rtdynm_mxmplrdmtr_src"},
				minimum_impeller_diameter: {machine_name:"field_rtdynm_mnmplrdmtr_av", enclosed:true},
				minimum_impeller_diameter_src: {machine_name:"field_rtdynm_mnmplrdmtr_src"},
				maximum_pump_speed: {machine_name:"field_rtdynm_mxmpmpspd_av", enclosed:true},
				maximum_pump_speed_src: {machine_name:"field_rtdynm_mxmpmpspd_src"},
				minimum_pump_speed: {machine_name:"field_rtdynm_mnmpmpspd_av", enclosed:true},
				minimum_pump_speed_src: {machine_name:"field_rtdynm_mnmpmpspd_src"},
				pump_type_and_classification: {machine_name:"field_rtdynm_pmptypndclsfc_av"},
				pump_type_and_classification_src: {machine_name:"field_rtdynm_pmptypndclsfc_src"},
				integrated_motor: {machine_name:"field_rtdynm_ntgrtdmtr_av"},
				integrated_motor_src: {machine_name:"field_rtdynm_ntgrtdmtr_src"},
				rated_motor_power: {machine_name:"field_rtdynm_rtdmtrpwr_av", enclosed:true},
				rated_motor_power_src: {machine_name:"field_rtdynm_rtdmtrpwr_src"},
				motor_voltage: {machine_name:"field_rtdynm_mtrvltg_av", enclosed:true},
				motor_voltage_src: {machine_name:"field_rtdynm_mtrvltg_src"},
				minimum_fluid_temperature: {machine_name:"field_rtdynm_mnmfldtmprtr_av", enclosed:true},
				minimum_fluid_temperature_src: {machine_name:"field_rtdynm_mnmfldtmprtr_src"},
				maximum_fluid_temperature: {machine_name:"field_rtdynm_mxmfldtmprtr_av", enclosed:true},
				maximum_fluid_temperature_src: {machine_name:"field_rtdynm_mxmfldtmprtr_src"},
				maximum_system_operating_pressure: {machine_name:"field_rtdynm_mxmsystmprtng_av", enclosed:true},
				maximum_system_operating_pressure_src: {machine_name:"field_rtdynm_mxmsystmprtng_src"},
				test_acceptance_grade: {machine_name:"field_rtdynm_tstcptncgrd_av"},
				test_acceptance_grade_src: {machine_name:"field_rtdynm_tstcptncgrd_src"},
				pump_industry_segment: {machine_name:"field_rtdynm_pmpndstrysgmn_av", multiple_list:true},
				pump_industry_segment_src: {machine_name:"field_rtdynm_pmpndstrysgmn_src"},
				product_data_sheet: {machine_name:"field_rtdynm_prdctdtsht_av", enclosed:true, label:"fid"},
				product_data_sheet_src: {machine_name:"field_rtdynm_prdctdtsht_src"},
				pump_performance_curve: {machine_name:"field_rtdynm_pmpprfrmnccrv_av",  enclosed:true, label:"fid"},
				pump_performance_curve_src: {machine_name:"field_rtdynm_pmpprfrmnccrv_src"},
				performance_map: {machine_name:"field_rtdynm_prfrmncmp_av", enclosed:true, label:"fid"},
				performance_map_src: {machine_name:"field_rtdynm_prfrmncmp_src"},
				measurement_source: {machine_name:"field_rtdynm_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			TRANSFORMER_FIELDS = {
				rated_power: {machine_name:"field_lwvltg_rtdpwr_av", enclosed:true},
				rated_power_src: {machine_name:"field_lwvltg_rtdpwr_src"},
				phase: {machine_name:"field_lwvltg_phs_av"},
				phase_src: {machine_name:"field_lwvltg_phs_src"},
				conductor_material: {machine_name:"field_lwvltg_cndctrmtrl_av"},
				conductor_material_src: {machine_name:"field_lwvltg_cndctrmtrl_src"},
				full_load_temperature_rise: {machine_name:"field_lwvltg_flldtmprtrrs_av", enclosed:true},
				full_load_temperature_rise_src: {machine_name:"field_lwvltg_flldtmprtrrs_src"},
				eddy_current_load_loss_fraction: {machine_name:"field_lwvltg_dycrntldlsfrc_av", enclosed:true},
				eddy_current_load_loss_fraction_src: {machine_name:"field_lwvltg_dycrntldlsfrc_src"},
				no_load_loss: {machine_name:"field_lwvltg_nldls_av", enclosed:true},
				no_load_loss_src: {machine_name:"field_lwvltg_nldls_src"},
				rated_load_loss: {machine_name:"field_lwvltg_rtdldls_av", enclosed:true},
				rated_load_loss_src: {machine_name:"field_lwvltg_rtdldls_src"},
				nameplate_efficiency: {machine_name:"field_lwvltg_nmpltfcncy_av", enclosed:true},
				nameplate_efficiency_src: {machine_name:"field_lwvltg_nmpltfcncy_src"},
				maximum_efficiency_point: {machine_name:"field_lwvltg_mxmfcncypnt_av", enclosed:true},
				maximum_efficiency_point_src: {machine_name:"field_lwvltg_mxmfcncypnt_src"},
				primary_voltage: {machine_name:"field_lwvltg_prmryvltg_av", enclosed:true},
				primary_voltage_src: {machine_name:"field_lwvltg_prmryvltg_src"},
				secondary_voltage: {machine_name:"field_lwvltg_scndryvltg_av", enclosed:true},
				secondary_voltage_src:{machine_name:"field_lwvltg_scndryvltg_src"},
				system_frequency: {machine_name:"field_lwvltg_systmfrqncy_av"},
				system_frequency_src: {machine_name:"field_lwvltg_systmfrqncy_src"},
				k_factor_rating: {machine_name:"field_lwvltg_kfctrrtng_av"},
				k_factor_rating_src: {machine_name:"field_lwvltg_kfctrrtng_src"},
				measurement_source: {machine_name:"field_lwvltg_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required: true},
				title: {machine_name:"title", required: true}
			}

			REFRIGERATED_CASE_FIELDS = {
				intended_use: {machine_name:"field_rfrgrt_ntnds_av"},
				intended_use_src: {machine_name:"field_rfrgrt_ntnds_src"},
				type_of_refrigerator: {machine_name:"field_rfrgrt_typfrfrgrtr_av"},
				type_of_refrigerator_src: {machine_name:"field_rfrgrt_typfrfrgrtr_src"},
				temperature_class: {machine_name:"field_rfrgrt_tmprtrcls_av"},
				temperature_class_src: {machine_name:"field_rfrgrt_tmprtrcls_src"},
				rated_total_cooling_capacity: {machine_name:"field_rfrgrt_rtdttlclngcpc_av", enclosed:true},
				rated_total_cooling_capacity_src: {machine_name:"field_rfrgrt_rtdttlclngcpc_src"},
				total_cooling_capacity_safety_factor: {machine_name:"field_rfrgrt_ttlclngcpctys_av", enclosed:true},
				total_cooling_capacity_safety_factor_src: {machine_name:"field_rfrgrt_ttlclngcpctys_src"},
				rated_latent_case_capacity: {machine_name:"field_rfrgrt_rtdltntcscpct_av", enclosed:true},
				rated_latent_case_capacity_src: {machine_name:"field_rfrgrt_rtdltntcscpct_src"},
				rated_evaporator_fan_power: {machine_name:"field_rfrgrt_rtdvprtrfnpwr_av", enclosed:true},
				rated_evaporator_fan_power_src: {machine_name:"field_rfrgrt_rtdvprtrfnpwr_src"},
				installed_evaporator_fan_power: {machine_name:"field_rfrgrt_nstldvprtrfnp_av", enclosed:true},
				installed_evaporator_fan_power_src: {machine_name:"field_rfrgrt_nstldvprtrfnp_src"},
				rated_case_lighting_power: {machine_name:"field_rfrgrt_rtdcslghtngpw_av", enclosed:true},
				rated_case_lighting_power_src: {machine_name:"field_rfrgrt_rtdcslghtngpw_src"},
				installed_case_lighting_power: {machine_name:"field_rfrgrt_nstldcslghtng_av", enclosed:true},
				installed_case_lighting_power_src: {machine_name:"field_rfrgrt_nstldcslghtng_src"},
				type_of_refrigerator_lighting: {machine_name:"field_rfrgrt_typfrfrgrtrlg_av"},
				type_of_refrigerator_lighting_src: {machine_name:"field_rfrgrt_typfrfrgrtrlg_src"},
				maximum_antisweat_door_heater_power: {machine_name:"field_rfrgrt_mxmntswtdrhtr_av", enclosed:true},
				maximum_antisweat_door_heater_power_src: {machine_name:"field_rfrgrt_mxmntswtdrhtr_src"},
				maximum_frame_heater_power: {machine_name:"field_rfrgrt_mxmfrmhtrpwr_av", enclosed:true},
				maximum_frame_heater_power_src: {machine_name:"field_rfrgrt_mxmfrmhtrpwr_src"},
				case_defrost_type: {machine_name:"field_rfrgrt_csdfrsttyp_av"},
				case_defrost_type_src: {machine_name:"field_rfrgrt_csdfrsttyp_src"},
				defrost_control_strategy: {machine_name:"field_rfrgrt_dfrstcntrlstr_av"},
				defrost_control_strategy_src: {machine_name:"field_rfrgrt_dfrstcntrlstr_src"},
				case_defrost_power: {machine_name:"field_rfrgrt_csdfrstpwr_av", enclosed:true},
				case_defrost_power_src: {machine_name:"field_rfrgrt_csdfrstpwr_src"},
				design_inlet_evaporator_temperature: {machine_name:"field_rfrgrt_dsgnltvprtrtm_av", enclosed:true},
				design_inlet_evaporator_temperature_src: {machine_name:"field_rfrgrt_dsgnltvprtrtm_src"},
				number_of_doors: {machine_name:"field_rfrgrt_nmbrfdrs_av", enclosed:true},
				number_of_doors_src: {machine_name:"field_rfrgrt_nmbrfdrs_src"},
				door_opening_method: {machine_name:"field_rfrgrt_drpngmthd_av"},
				door_opening_method_src: {machine_name:"field_rfrgrt_drpngmthd_src"},
				case_height: {machine_name:"field_rfrgrt_cshght_av", enclosed:true},
				case_height_src: {machine_name:"field_rfrgrt_cshght_src"},
				case_length: {machine_name:"field_rfrgrt_cslngth_av", enclosed:true},
				case_length_src: {machine_name:"field_rfrgrt_cslngth_src"},
				total_display_area: {machine_name:"field_rfrgrt_ttldsplyr_av", enclosed:true},
				total_display_area_src: {machine_name:"field_rfrgrt_ttldsplyr_src"},
				net_usable_volume: {machine_name:"field_rfrgrt_ntsblvlm_av", enclosed:true},
				net_usable_volume_src: {machine_name:"field_rfrgrt_ntsblvlm_src"},
				night_curtain: {machine_name:"field_rfrgrt_nghtcrtn_av"},
				night_curtain_src: {machine_name:"field_rfrgrt_nghtcrtn_src"},
				measurement_source: {machine_name:"field_rfrgrt_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required:true},
				title: {machine_name:"title", required:true}
			}

			HYBRID_UNITARY_HVAC_FIELDS = {
				product_description: {machine_name:"field_hybrdn_prdctdscrptn_av"},
				product_description_src: {machine_name:"field_hybrdn_prdctdscrptn_src"},
				notes: {machine_name:"field_hybrdn_nts_av"},
				notes_src: {machine_name:"field_hybrdn_nts_src"},
				intended_climate_zones: {machine_name:"field_hybrdn_ntndclmtzns_av", multiple_list:true},
				intended_climate_zones_src: {machine_name:"field_hybrdn_ntndclmtzns_src"},
				intended_building_types: {machine_name:"field_hybrdn_ntndbldngtyps_av", multiple_list:true},
				intended_building_types_src: {machine_name:"field_hybrdn_ntndbldngtyps_src"},
				product_features: {machine_name:"field_hybrdn_prdctftrs_av", multiple_list:true},
				product_features_src: {machine_name:"field_hybrdn_prdctftrs_src"},
				intended_dehumidification: {machine_name:"field_hybrdn_ntndfrdhmdfct_av"},
				intended_dehumidification_src: {machine_name:"field_hybrdn_ntndfrdhmdfct_src"},
				intended_heating: {machine_name:"field_hybrdn_ntndfrhtng_av"},
				intended_heating_src: {machine_name:"field_hybrdn_ntndfrhtng_src"},
				intended_cooling: {machine_name:"field_hybrdn_ntndfrclng_av"},
				intended_cooling_src: {machine_name:"field_hybrdn_ntndfrclng_src"},
				intended_ventilation: {machine_name:"field_hybrdn_ntndfrvntl_av"},
				intended_ventilation_src: {machine_name:"field_hybrdn_ntndfrvntl_src"},
				minimum_osaf: {machine_name:"field_hybrdn_mnmsf_av", enclosed:true},
				minimum_osaf_src: {machine_name:"field_hybrdn_mnmsf_src"},
				maximum_osaf: {machine_name:"field_hybrdn_mxmsf_av", enclosed:true},
				maximum_osaf_src: {machine_name:"field_hybrdn_mxmsf_src"},
				minimum_supply_air_mass_flow_rate: {machine_name:"field_hybrdn_mnmsplyrmsflw_av", enclosed:true},
				minimum_supply_air_mass_flow_rate_src: {machine_name:"field_hybrdn_mnmsplyrmsflw_src"},
				maximum_supply_air_mass_flow_rate: {machine_name:"field_hybrdn_mxmsplyrmsflw_av", enclosed:true},
				maximum_supply_air_mass_flow_rate_src: {machine_name:"field_hybrdn_mxmsplyrmsflw_src"},
				fuel_types: {machine_name:"field_hybrdn_fltyps_av",multiple_list:true},
				fuel_types_src: {machine_name:"field_hybrdn_fltyps_src"},
				water_use: {machine_name:"field_hybrdn_wtrs_av"},
				water_use_src: {machine_name:"field_hybrdn_wtrs_src"},
				max_allowable_scaling_factor: {machine_name:"field_hybrdn_mxlwblsclngfc_av", enclosed:true},
				max_allowable_scaling_factor_src: {machine_name:"field_hybrdn_mxlwblsclngfc_src"},
				min_allowable_scaling_factor: {machine_name:"field_hybrdn_mnlwblsclngfc_av", enclosed:true},
				min_allowable_scaling_factor_src: {machine_name:"field_hybrdn_mnlwblsclngfc_av"},
				control_documentation: {machine_name:"field_hybrdn_cntrldcmntn_av", enclosed:true, label: "fid", multiple_list:true},
				control_documentation_src: {machine_name:"field_hybrdn_cntrldcmntn_src"},
				engineering_documentation: {machine_name:"field_hybrdn_ngnrngdcmntn_av", enclosed:true, label: "fid", multiple_list:true},
				engineering_documentation_src: {machine_name:"field_hybrdn_ngnrngdcmntn_src"},
				number_operating_modes: {machine_name:"field_hybrdn_nmbrfprtngmds_av", enclosed:true},
				number_operating_modes_src: {machine_name:"field_hybrdn_nmbrfprtngmds_src"},
				performance_map_operating_mode_0: {machine_name:"field_hybrdn_prfrmncmpfrprtn_av", enclosed:true, label: "fid"},
				performance_map_operating_mode_0_src: {machine_name:"field_hybrdn_prfrmncmpfrprtn_src"},
				performance_map_each_operating_mode: {machine_name:"field_hybrdn_prfrmncmpfrchp_av", enclosed:true, label: "fid", multiple_list:true},
				performance_map_each_operating_mode_src: {machine_name:"field_hybrdn_prfrmncmpfrchp_src"},
				nominal_performance_information: {machine_name:"field_hybrdn_nmnlprfrmncnf_av", enclosed:true, label: "fid"},
				nominal_performance_information_src: {machine_name:"field_hybrdn_nmnlprfrmncnf_src"},
				hot_dry_operating_mode: {machine_name:"field_hybrdn_htdryprtngmd_av"},
				hot_dry_operating_mode_src: {machine_name:"field_hybrdn_htdryprtngmd_src"},
				hot_dry_osaf: {machine_name:"field_hybrdn_htdrysf_av", enclosed:true},
				hot_dry_osaf_src: {machine_name:"field_hybrdn_htdrysf_src"},
				hot_dry_supply_air_mass_flow_rate: {machine_name:"field_hybrdn_htdrysplyrmsflw_av", enclosed:true},
				hot_dry_supply_air_mass_flow_rate_src: {machine_name:"field_hybrdn_htdrysplyrmsflw_src"},
				hot_dry_supply_air_temperature: {machine_name:"field_hybrdn_htdrysplyrtmprt_av", enclosed:true},
				hot_dry_supply_air_temperature_src: {machine_name:"field_hybrdn_htdrysplyrtmprt_src"},
				hot_dry_supply_air_humidity_ratio: {machine_name:"field_hybrdn_htdrysplrtmprt_av", enclosed:true},
				hot_dry_supply_air_humidity_ratio_src: {machine_name:"field_hybrdn_htdrysplrtmprt_src"},
				hot_dry_system_cooling_capacity: {machine_name:"field_hybrdn_htdrysystmcln_av", enclosed:true},
				hot_dry_system_cooling_capacity_src: {machine_name:"field_hybrdn_htdrysystmcln_src"},
				hot_dry_sensible_room_cooling_capacity: {machine_name:"field_hybrdn_htdrysnsblrmc_av", enclosed:true},
				hot_dry_sensible_room_cooling_capacity_src: {machine_name:"field_hybrdn_htdrysnsblrmc_src"},
				hot_dry_sensible_system_cooling_capacity: {machine_name:"field_hybrdn_htdrysnsblsys_av", enclosed:true},
				hot_dry_sensible_system_cooling_capacity_src: {machine_name:"field_hybrdn_htdrysnsblsys_src"},
				hot_dry_moisture_removal_capacity: {machine_name:"field_hybrdn_htdrymstrrmvl_av", enclosed:true},
				hot_dry_moisture_removal_capacity_src: {machine_name:"field_hybrdn_htdrymstrrmvl_src"},
				hot_dry_system_efficiency: {machine_name:"field_hybrdn_htdrysystmfcn_av", enclosed:true},
				hot_dry_system_efficiency_src: {machine_name:"field_hybrdn_htdrysystmfcn_src"},
				hot_dry_sensible_room_efficiency: {machine_name:"field_hybrdn_htdrysnsblrmf_av", enclosed:true},
				hot_dry_sensible_room_efficiency_src: {machine_name:"field_hybrdn_htdrysnsblrmf_src"},
				hot_dry_sensible_system_efficiency: {machine_name:"field_hybrdn_htdrysnsblsya_av", enclosed:true},
				hot_dry_sensible_system_efficiency_src: {machine_name:"field_hybrdn_htdrysnsblsya_src"},
				hot_dry_moisture_removal_efficiency: {machine_name:"field_hybrdn_htdrymstrrmva_av", enclosed:true},
				hot_dry_moisture_removal_efficiency_src: {machine_name:"field_hybrdn_htdrymstrrmva_src"},
				warm_humid_operating_mode: {machine_name:"field_hybrdn_wrmhmdprtng_av"},
				warm_humid_operating_mode_src: {machine_name:"field_hybrdn_wrmhmdprtng_src"},
				warm_humid_osaf: {machine_name:"field_hybrdn_wrmhmdsf_av", enclosed:true},
				warm_humid_osaf_src: {machine_name:"field_hybrdn_wrmhmdsf_src"},
				warm_humid_supply_air_mass_flow_rate: {machine_name:"field_hybrdn_wrmhmdsplyr_av", enclosed:true},
				warm_humid_supply_air_mass_flow_rate_src: {machine_name:"field_hybrdn_wrmhmdsplyr_src"},
				warm_humid_supply_air_temperature: {machine_name:"field_hybrdn_wrmhmdsplyrt_av", enclosed:true},
				warm_humid_supply_air_temperature_src: {machine_name:"field_hybrdn_wrmhmdsplyrt_src"},
				warm_humid_supply_air_humidity_ratio: {machine_name:"field_hybrdn_wrmhmdsplrhm_av", enclosed:true},
				warm_humid_supply_air_humidity_ratio_src: {machine_name:"field_hybrdn_wrmhmdsplrhm_src"},
				warm_humid_system_cooling_capacity: {machine_name:"field_hybrdn_wrmhmdsystmcl_av", enclosed:true},
				warm_humid_system_cooling_capacity_src: {machine_name:"field_hybrdn_wrmhmdsystmcl_src"},
				warm_humid_sensible_room_cooling_capacity: {machine_name:"field_hybrdn_wrmhmdsnsblrm_av", enclosed:true},
				warm_humid_sensible_room_cooling_capacity_src: {machine_name:"field_hybrdn_wrmhmdsnsblrm_src"},
				warm_humid_sensible_system_cooling_capacity: {machine_name:"field_hybrdn_wrmhmdsnsblsy_av", enclosed:true},
				warm_humid_sensible_system_cooling_capacity_src: {machine_name:"field_hybrdn_wrmhmdsnsblsy_src"},
				warm_humid_moisture_removal_capacity: {machine_name:"field_hybrdn_wrmhmdmstrrmv_av", enclosed:true},
				warm_humid_moisture_removal_capacity_src: {machine_name:"field_hybrdn_wrmhmdmstrrmv_src"},
				warm_humid_system_efficiency: {machine_name:"field_hybrdn_wrmhmdsystmfc_av", enclosed:true},
				warm_humid_system_efficiency_src: {machine_name:"field_hybrdn_wrmhmdsystmfc_src"},
				warm_humid_sensible_room_efficiency: {machine_name:"field_hybrdn_wrmhmdsnsblra_av", enclosed:true},
				warm_humid_sensible_room_efficiency_src: {machine_name:"field_hybrdn_wrmhmdsnsblra_src"},
				warm_humid_sensible_system_efficiency: {machine_name:"field_hybrdn_wrmhmdsnsblsa_av", enclosed:true},
				warm_humid_sensible_system_efficiency_src: {machine_name:"field_hybrdn_wrmhmdsnsblsa_src"},
				warm_humid_moisture_removal_efficiency: {machine_name:"field_hybrdn_wrmhmdmstrrma_av", enclosed:true},
				warm_humid_moisture_removal_efficiency_src: {machine_name:"field_hybrdn_wrmhmdmstrrma_src"},
				ahri_conditions_operating_mode: {machine_name:"field_hybrdn_hrcndtnsprtng_av"},
				ahri_conditions_operating_mode_src: {machine_name:"field_hybrdn_hrcndtnsprtng_src"},
				ahri_conditions_osaf: {machine_name:"field_hybrdn_hrcndtnssf_av", enclosed:true},
				ahri_conditions_osaf_src: {machine_name:"field_hybrdn_hrcndtnssf_src"},
				ahri_conditions_supply_air_mass_flow_rate: {machine_name:"field_hybrdn_hrcndtnsplyr_av", enclosed:true},
				ahri_conditions_supply_air_mass_flow_rate_src: {machine_name:"field_hybrdn_hrcndtnsplyr_src"},
				ahri_conditions_supply_air_temperature: {machine_name:"field_hybrdn_hrcndtnspltmp_av", enclosed:true},
				ahri_conditions_supply_air_temperature_src: {machine_name:"field_hybrdn_hrcndtnspltmp_src"},
				ahri_conditions_supply_air_humidity_ratio: {machine_name:"field_hybrdn_hrcndtnsplhm_av", enclosed:true},
				ahri_conditions_supply_air_humidity_ratio_src: {machine_name:"field_hybrdn_hrcndtnsplhm_src"},
				ahri_conditions_system_cooling_capacity: {machine_name:"field_hybrdn_hrcndtnssystm_av", enclosed:true},
				ahri_conditions_system_cooling_capacity_src: {machine_name:"field_hybrdn_hrcndtnssystm_src"},
				ahri_conditions_sensible_room_cooling_capacity: {machine_name:"field_hybrdn_hrcndtnssnsbl_av", enclosed:true},
				ahri_conditions_sensible_room_cooling_capacity_src: {machine_name:"field_hybrdn_hrcndtnssnsbl_src"},
				ahri_conditions_sensible_system_cooling_capacity: {machine_name:"field_hybrdn_hrcndtnssnsba_av", enclosed:true},
				ahri_conditions_sensible_system_cooling_capacity_src: {machine_name:"field_hybrdn_hrcndtnssnsba_src"},
				ahri_conditions_moisture_removal_capacity: {machine_name:"field_hybrdn_hrcndtnsmstrr_av", enclosed:true},
				ahri_conditions_moisture_removal_capacity_src: {machine_name:"field_hybrdn_hrcndtnsmstrr_src"},
				ahri_conditions_system_efficiency: {machine_name:"field_hybrdn_hrcndtnssysta_av", enclosed:true},
				ahri_conditions_system_efficiency_src: {machine_name:"field_hybrdn_hrcndtnssysta_src"},
				ahri_conditions_sensible_room_efficiency: {machine_name:"field_hybrdn_hrsnsblra_av", enclosed:true},
				ahri_conditions_sensible_room_efficiency_src: {machine_name:"field_hybrdn_hrsnsblra_src"},
				ahri_conditions_sensible_system_efficiency: {machine_name:"field_hybrdn_hrsnsblsa_av", enclosed:true},
				ahri_conditions_sensible_system_efficiency_src: {machine_name:"field_hybrdn_hrsnsblsa_src"},
				ahri_conditions_moisture_removal_efficiency: {machine_name:"field_hybrdn_hrcndtnsmstra_av", enclosed:true},
				ahri_conditions_moisture_removal_efficiency_src: {machine_name:"field_hybrdn_hrcndtnsmstra_src"},
				measurement_source: {machine_name:"field_rfrgrt_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required:true},
				title: {machine_name:"title", required:true}
			}

			MINI_SPLIT_SYSTEM_FIELDS = {
				rated_cooling_capacity: {machine_name:"field_mnsplt_rtdclngcpcty_av", enclosed:true},
				rated_cooling_capacity_src: {machine_name:"field_mnsplt_rtdclngcpcty_src"},
				rated_heating_capacity: {machine_name:"field_mnsplt_rtdhtngcpcty_av", enclosed:true},
				rated_heating_capacity_src: {machine_name:"field_mnsplt_rtdhtngcpcty_src"},
				energy_efficiency_ratio: {machine_name:"field_mnsplt_nrgyfcncyrt_av", enclosed:true},
				energy_efficiency_ratio_src: {machine_name:"field_mnsplt_nrgyfcncyrt_src"},
				heating_coefficient_of_performance: {machine_name:"field_mnsplt_htngcfcntfprf_av", enclosed:true},
				heating_coefficient_of_performance_src: {machine_name:"field_mnsplt_htngcfcntfprf_src"},
				rated_integrated_energy_efficiency_ratio: {machine_name:"field_mnsplt_rtdntgrtdnrgy_av", enclosed:true},
				rated_integrated_energy_efficiency_ratio_src: {machine_name:"field_mnsplt_rtdntgrtdnrgy_src"},
				rated_seasonal_energy_efficiency_ratio: {machine_name:"field_mnsplt_rtdssnlnrgyfc_av", enclosed:true},
				rated_seasonal_energy_efficiency_ratio_src: {machine_name:"field_mnsplt_rtdssnlnrgyfc_src"},
				rated_heating_seasonal_performance_factor: {machine_name:"field_mnsplt_rtdhtngssnlpr_av", enclosed:true},
				rated_heating_seasonal_performance_factor_src: {machine_name:"field_mnsplt_rtdhtngssnlpr_src"},
				supply_fan_speed_control: {machine_name:"field_mnsplt_splyfnspdcntr_av"},
				supply_fan_speed_control_src: {machine_name:"field_mnsplt_splyfnspdcntr_src"},
				compressor_staging: {machine_name:"field_mnsplt_cmprsrstgng_av"},
				compressor_staging_src: {machine_name:"field_mnsplt_cmprsrstgng_src"},
				supply_fan_flowrate: {machine_name:"field_mnsplt_splyfnflwrt_av", enclosed:true},
				supply_fan_flowrate_src: {machine_name:"field_mnsplt_splyfnflwrt_src"},
				supply_fan_pressure_rise: {machine_name:"field_mnsplt_splyfnprsrrs_av", enclosed:true},
				supply_fan_pressure_rise_src: {machine_name:"field_mnsplt_splyfnprsrrs_src"},
				minimum_outdoor_drybulb_for_heat_pump_operation: {machine_name:"field_mnsplt_mnmtdrdryblbf_av", enclosed:true},
				minimum_outdoor_drybulb_for_heat_pump_operation_src: {machine_name:"field_mnsplt_mnmtdrdryblbf_src"},
				defrost_mechanism: {machine_name:"field_mnsplt_dfrstmchnsm_av"},
				defrost_mechanism_src: {machine_name:"field_mnsplt_dfrstmchnsm_src"},
				defrost_control_strategy: {machine_name:"field_mnsplt_dfrstcntrlstr_av"},
				defrost_control_strategy_src: {machine_name:"field_mnsplt_dfrstcntrlstr_src"},
				defrost_power: {machine_name:"field_mnsplt_dfrstpwr_av", enclosed:true},
				defrost_power_src: {machine_name:"field_mnsplt_dfrstpwr_src"},
				supplemental_heating: {machine_name:"field_mnsplt_splmntlhtng_av"},
				supplemental_heating_src: {machine_name:"field_mnsplt_splmntlhtng_src"},
				supplemental_heating_capacity: {machine_name:"field_mnsplt_splmntlhtngcp_av", enclosed:true},
				supplemental_heating_capacity_src: {machine_name:"field_mnsplt_splmntlhtngcp_src"},
				supplemental_heating_stages: {machine_name:"field_mnsplt_splmntlhtngst_av", enclosed:true},
				supplemental_heating_stages_src: {machine_name:"field_mnsplt_splmntlhtngst_src"},
				crankcase_heater_power: {machine_name:"field_mnsplt_crnkcshtrpwr_av", enclosed:true},
				crankcase_heater_power_src: {machine_name:"field_mnsplt_crnkcshtrpwr_src"},
				refrigerant: {machine_name:"field_mnsplt_rfrgrnt_av"},
				refrigerant_src: {machine_name:"field_mnsplt_rfrgrnt_src"},
				cooling_performance_map: {machine_name:"field_mnsplt_clngprfrmncmp_av", enclosed:true, label: "fid"},
				cooling_performance_map_src: {machine_name:"field_mnsplt_clngprfrmncmp_src"},
				heating_performance_map: {machine_name:"field_mnsplt_htngprfrmncmp_av", enclosed:true, label: "fid"},
				heating_performance_map_src: {machine_name:"field_mnsplt_htngprfrmncmp_src"},
				product_data_sheet: {machine_name:"field_mnsplt_prdctdtsht_av", enclosed:true, label: "fid"},
				product_data_sheet_src: {machine_name:"field_mnsplt_prdctdtsht_src"},
				measurement_source: {machine_name:"field_mnsplt_measurement_source"},
				product_ref: {machine_name:"field_product_ref", required:true},
				title: {machine_name:"title", required:true}
			}

			HWBoiler =  Struct.new(*HOT_WATER_BOILER_FIELDS.keys)
			SteamBoiler =  Struct.new(*STEAM_BOILER_FIELDS.keys) 
			Chiller =  Struct.new(*CHILLER_FIELDS.keys)
			Ballast =  Struct.new(*BALLAST_FIELDS.keys)
			RooftopUnit =  Struct.new(*ROOFTOP_UNIT_FIELDS.keys)
			HybridUnitaryHVAC = Struct.new(*HYBRID_UNITARY_HVAC_FIELDS.keys)
			SSLLuminaire =  Struct.new(*SSL_LUMINAIRE_FIELDS.keys)
			SSLLamp =  Struct.new(*SSL_LAMP_FIELDS.keys)
			NonSSLLuminaire =  Struct.new(*NON_SSL_LUMINAIRE_FIELDS.keys)
			NonSSLLamp =  Struct.new(*NON_SSL_LAMP_FIELDS.keys)
			PVModule = Struct.new(*PV_MODULE_FIELDS.keys)
			HPWH = Struct.new(*HEAT_PUMP_WATER_HEATER_FIELDS.keys)
      			Inverter = Struct.new(*INVERTER_FIELDS.keys)
      			IndoorUnit = Struct.new(*INDOOR_UNIT_FIELDS.keys)
      			OutdoorUnit = Struct.new(*OUTDOOR_UNIT_FIELDS.keys)
      			UnitHeater = Struct.new(*UNIT_HEATER_FIELDS.keys)
      			Compressor = Struct.new(*COMPRESSOR_FIELDS.keys)
      			Pump = Struct.new(*PUMP_FIELDS.keys)
      			Transformer = Struct.new(*TRANSFORMER_FIELDS.keys)
      			RefrigeratedCase = Struct.new(*REFRIGERATED_CASE_FIELDS.keys)
      			MiniSplitSystem = Struct.new(*MINI_SPLIT_SYSTEM_FIELDS.keys)

			def post_performance_node(performance)
				data = jsonify_performance_data(performance)
				response = post("content", data)
			end


			def build_performance_node(options={})
				required_fields = []
				arguments = []
				fields = {}
				performance_class = nil

				case options[:type]
				when "nnslmp"
					fields = NON_SSL_LAMP_FIELDS
					performance_class = NonSSLLamp
				when "nnslmn"
					fields = NON_SSL_LUMINAIRE_FIELDS
					performance_class = NonSSLLuminaire
				when "htwtrb"
					fields = HOT_WATER_BOILER_FIELDS
					performance_class = HWBoiler
				when "stmblr"
					fields = STEAM_BOILER_FIELDS
					performance_class = SteamBoiler
				when "slrplc"
					fields = SSL_LAMP_FIELDS
					performance_class = SSLLamp
				when "lctrcl"
					fields = CHILLER_FIELDS
					performance_class = Chiller
				when "rftpnt"
					fields = ROOFTOP_UNIT_FIELDS
					performance_class = RooftopUnit
				when "slmnrs"
					fields = SSL_LUMINAIRE_FIELDS
					performance_class = SSLLuminaire
				when "lmpbls"
					fields = BALLAST_FIELDS
					performance_class = Ballast
				when "phtvlt"
					fields = PV_MODULE_FIELDS
					performance_class = PVModule
				when "htpmpw"
					fields = HEAT_PUMP_WATER_HEATER_FIELDS
					performance_class = HPWH
				when "nvrtr"
				  	fields = INVERTER_FIELDS
				  	performance_class = Inverter
				when "ndrnt"
				  	fields = INDOOR_UNIT_FIELDS
				  	performance_class = IndoorUnit
				when "tdrnt"
				  	fields = OUTDOOR_UNIT_FIELDS
				  	performance_class = OutdoorUnit
				when "gsfrdn"
				  	fields = UNIT_HEATER_FIELDS
				  	performance_class = UnitHeater
				when "pstvds"
				  	fields = COMPRESSOR_FIELDS
				  	performance_class = Compressor
				when "rtdynm"
				  	fields = PUMP_FIELDS
				  	performance_class = Pump
				when "lwvltg"
				  	fields = TRANSFORMER_FIELDS
				  	performance_class = Transformer
				when "rfrgrt"
				  	fields = REFRIGERATED_CASE_FIELDS
				  	performance_class = RefrigeratedCase
				when "mnsplt"
				  	fields = MINI_SPLIT_SYSTEM_FIELDS
				  	performance_class = MiniSplitSystem
				when "hybrdn"
				  	fields = HYBRID_UNITARY_HVAC_FIELDS
				  	performance_class = HybridUnitaryHVAC
				when nil
					return nil
				end

				fields.each do |key, value|
					required_fields << key if value[:required]
					arguments << options[key]
				end

				required_fields.each do |key|
					return nil if options[key].nil?
				end

				return performance_class.new(*arguments);
			end

			def jsonify_performance_data(performance)
				jsonobject = {"title" => performance[:title]}
				product_ref = performance[:product_ref]

				case performance.class.name.split('::').last
				when "NonSSLLamp"
					fields = NON_SSL_LAMP_FIELDS
					jsonobject["type"] = "nnslmp"
				when "SSLLamp"
					fields = SSL_LAMP_FIELDS
					jsonobject["type"] = "slrplc"
				when "HWBoiler"
					fields = HOT_WATER_BOILER_FIELDS
					jsonobject["type"] = "htwtrb"
				when "SteamBoiler"
					fields = STEAM_BOILER_FIELDS
					jsonobject["type"] = "stmblr"
				when "Ballast"
					fields = BALLAST_FIELDS
					jsonobject["type"] = "lmpbls"
				when "NonSSLLuminaire"
					fields = NON_SSL_LUMINAIRE_FIELDS
					jsonobject["type"] = "nnslmn"
				when "SSLLuminaire"
					fields = SSL_LUMINAIRE_FIELDS
					jsonobject["type"] = "slmnrs"
				when "Chiller"
					fields = CHILLER_FIELDS
					jsonobject["type"] = "lctrcl"
				when "RooftopUnit"
					fields = ROOFTOP_UNIT_FIELDS
					jsonobject["type"] = "rftpnt"
				when "PVModule"
					fields = PV_MODULE_FIELDS
					jsonobject["type"] = "phtvlt"
				when "HPWH"
					fields = HEAT_PUMP_WATER_HEATER_FIELDS
					jsonobject["type"] = "htpmpw"
				when "IndoorUnit"
				  	fields = INDOOR_UNIT_FIELDS
				  	jsonobject["type"] = "ndrnt"
				when "OutdoorUnit"
				  	fields = OUTDOOR_UNIT_FIELDS
				  	jsonobject["type"] = "tdrnt"
				when "Inverter"
				  	fields = INVERTER_FIELDS
				  	jsonobject["type"] = "nvrtr"
				when "UnitHeater"
				  	fields = UNIT_HEATER_FIELDS
				  	jsonobject["type"] = "gsfrdn"
				when "Compressor"
				  	fields = COMPRESSOR_FIELDS
				  	jsonobject["type"] = "pstvds"
				when "Pump"
				  	fields = PUMP_FIELDS
				  	jsonobject["type"] = "rtdynm"
				when "Transformer"
				  	fields = TRANSFORMER_FIELDS
				  	jsonobject["type"] = "lwvltg"
				when "RefrigeratedCase"
				  	fields = REFRIGERATED_CASE_FIELDS
				  	jsonobject["type"] = "rfrgrt"
				when "MiniSplitSystem"
				  	fields = MINI_SPLIT_SYSTEM_FIELDS
				  	jsonobject["type"] = "mnsplt"
				when "HybridUnitaryHVAC"
					fields = HYBRID_UNITARY_HVAC_FIELDS
					jsonobject["type"] = "hybrdn"
				when nil
					return nil
				end

				performance.each_pair do |name, value|

					if name != :product_ref && name != :title
						if !value.nil?
							label = fields[name][:label] || "value"
							contents = {label => value}
							contents = [{label => value}] if fields[name][:enclosed]
							contents = value.split(',') if fields[name][:multiple_list]
							if fields[name][:multiple]
								value = value.split(',')
								contents = []
								value.each do |multi_value|
									contents << {label => multi_value}
								end
							end
							jsonobject[fields[name][:machine_name]] = {"und" => contents}
						end
					end
				end

				JSON.generate(
					{"product" =>
					 {"uuid" => product_ref},
					 "performance" => jsonobject
					}
				)

			end
		end
	end
end
