require 'faraday'
require File.expand_path('../version', __FILE__)

module TPEX
	module Configuration

    	VALID_OPTIONS_KEYS =  [
    		:username,
    		:password,
    		:access_token,
    		:endpoint,
            :access_endpoint,
    		:format,
    		:user_agent,
    		:cookie,
            :roles,
            :logging
    	].freeze

    	VALID_FORMATS = [
          :json
        ].freeze

        # Default config values
        DEFAULT_FORMAT = :json
        DEFAULT_USERNAME = nil
        DEFAULT_PASSWORD = nil
        DEFAULT_ACCESS_TOKEN = nil
        DEFAULT_ENDPOINT = 'http://tp-dev.development.nrel.gov/api/'
        DEFAULT_USER_AGENT = "TPEX Ruby Client #{TPEX::VERSION}".freeze
        DEFAULT_COOKIE = nil
        DEFAULT_ROLES = ['Authenticated']
        DEFAULT_LOGGING = nil



		attr_accessor *VALID_OPTIONS_KEYS

        # When this module is extended, set all configuration options to their default values
        def self.extended(base)
          base.reset
        end

        # Convenience method to allow configuration options to be set in a block
        def configure
          yield self
        end

        # Create a hash of options and their values
        def options
          VALID_OPTIONS_KEYS.inject({}) do |option, key|
            option.merge!(key => send(key))
          end
        end

        # Reset all configuration options to defaults
        def reset
    	    self.format = DEFAULT_FORMAT
    	    self.username = DEFAULT_USERNAME
    	    self.password = DEFAULT_PASSWORD
    	    self.access_token = DEFAULT_ACCESS_TOKEN
    	    self.endpoint = DEFAULT_ENDPOINT
    	    self.user_agent = DEFAULT_USER_AGENT
    	    self.cookie = DEFAULT_COOKIE
            self.roles = DEFAULT_ROLES
            self.logging = DEFAULT_LOGGING
        end

 	end
end
